% Auto-generated chapter 53 for muslim
% Hadiths in this chapter: 102

\hadithdefcmd{muslim}{7130}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، وَحُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُفَّتِ الْجَنَّةُ بِالْمَكَارِهِ وَحُفَّتِ النَّارُ بِالشَّهَوَاتِ ‏"‏ ‏.‏\hadithno{7130}\hadithtrans{Anas b. Malik reported:The Paradise is surrounded by hardships and the Hell-Fire is surrounded by temptations}}
\hadithdefcmd{muslim}{7131}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7131}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7132}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ زُهَيْرٌ حَدَّثَنَا وَقَالَ، سَعِيدٌ أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَعْدَدْتُ لِعِبَادِيَ الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ وَلاَ أُذُنٌ سَمِعَتْ وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏"‏ ‏.‏ مِصْدَاقُ ذَلِكَ فِي كِتَابِ اللَّهِ ‏\{‏ فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ جَزَاءً بِمَا كَانُوا يَعْمَلُونَ‏\}‏\hadithno{7132}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying that:Allah the Exalted and Glorious, said: I have prepared for My pious servants which no eye has ever seen, and no ear has ever heard, and no human heart has ever perceived but it is testified by the Book of Allah. He then recited:" No soul knows what comfort has been concealed from them, as a reward for what they did". (xxxii)}}
\hadithdefcmd{muslim}{7133}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَعْدَدْتُ لِعِبَادِيَ الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ وَلاَ أُذُنٌ سَمِعَتْ وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ذُخْرًا بَلْهَ مَا أَطْلَعَكُمُ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{7133}\hadithtrans{Abu Huraira reported that Allah's Apostle (ﷺ) said:Allah, the Exalted and Glorious, said: I have prepared for My pious servants which no eye (has ever) seen, no ear has (ever) heard and no human heart has ever perceived those bounties leaving apart (those bounties) about which Allah has informed you}}
\hadithdefcmd{muslim}{7134}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَعْدَدْتُ لِعِبَادِيَ الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ وَلاَ أُذُنٌ سَمِعَتْ وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏.‏ ذُخْرًا بَلْهَ مَا أَطْلَعَكُمُ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{‏ فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ‏\}‏\hadithno{7134}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) said that Allah, the Exalted and Glorious, said:I have prepared for My pious servants which the eye has seen not, and the ear has heard not and no human heart has ever perceived such bounties leaving aside those about which Allah has informed you. He then recited:" No soul knows what comfort has been hidden for thein}}
\hadithdefcmd{muslim}{7135}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أَبُو صَخْرٍ، أَنَّ أَبَا حَازِمٍ، حَدَّثَهُ قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، يَقُولُ شَهِدْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَجْلِسًا وَصَفَ فِيهِ الْجَنَّةَ حَتَّى انْتَهَى ثُمَّ قَالَ صلى الله عليه وسلم فِي آخِرِ حَدِيثِهِ ‏"‏ فِيهَا مَا لاَ عَيْنٌ رَأَتْ وَلاَ أُذُنٌ سَمِعَتْ وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏"‏ ‏.‏ ثُمَّ اقْتَرَأَ هَذِهِ الآيَةَ ‏\{‏ تَتَجَافَى جُنُوبُهُمْ عَنِ الْمَضَاجِعِ يَدْعُونَ رَبَّهُمْ خَوْفًا وَطَمَعًا وَمِمَّا رَزَقْنَاهُمْ يُنْفِقُونَ * فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ جَزَاءً بِمَا كَانُوا يَعْمَلُونَ‏\}‏ ‏.‏\hadithno{7135}\hadithtrans{Sahl b. Sa'd as-Sa'idi reported:I was in the company of Allah's Messenger (ﷺ) that he gave a description of Paradise and then Allah's Apostle (ﷺ) concluded with these words: There would be bounties which the eye has not seen and the ear has not heard and no human heart has ever perceived them. He then recited this verse:" They forsake (their) beds, calling upon their Lord in fear and in hope, and spend out of what We have given them. So no soul knows what refreshment of the eyes is hidden for them: a reward for what they did" (xxxii)}}
\hadithdefcmd{muslim}{7136}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ سَنَةٍ ‏"‏ ‏.‏\hadithno{7136}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:In Paradise, there is a tree under the shadow of which a rider can travel for a hundred years}}
\hadithdefcmd{muslim}{7137}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَزَادَ ‏ "‏ لاَ يَقْطَعُهَا ‏"‏ ‏.‏\hadithno{7137}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters with the addition of these words:" He will not be able to cover this distance}}
\hadithdefcmd{muslim}{7139}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَبِي، حَازِمٍ عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ لاَ يَقْطَعُهَا ‏"‏ ‏.‏ قَالَ أَبُو حَازِمٍ فَحَدَّثْتُ بِهِ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ الزُّرَقِيَّ، فَقَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ شَجَرَةً يَسِيرُ الرَّاكِبُ الْجَوَادَ الْمُضَمَّرَ السَّرِيعَ مِائَةَ عَامٍ مَا يَقْطَعُهَا ‏"‏ ‏.‏\hadithno{7139}\hadithtrans{Sahl b. Sa'd reported Allah's Messenger (ﷺ) as saying:In Paradise, there is a tree under the shadow of which a rider can travel for a hundred years without covering (the distance) completely. This hadith has also been transmitted on the authority of Abu Sa'id al-Khudri that Allah's Apostle (ﷺ) is reported to have said: In Paradise, there is a tree under the shadow of which a rider of a fine and swift-footed horse would travel for a hundred years without covering the distance completely. There would be the pleasure of Allah for the inmates of Paradise and He would never be annoyed with them}}
\hadithdefcmd{muslim}{7140}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَهْمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَالِكُ، بْنُ أَنَسٍ ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَقُولُ لأَهْلِ الْجَنَّةِ يَا أَهْلَ الْجَنَّةِ ‏.‏ فَيَقُولُونَ لَبَّيْكَ رَبَّنَا وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ ‏.‏ فَيَقُولُ هَلْ رَضِيتُمْ فَيَقُولُونَ وَمَا لَنَا لاَ نَرْضَى يَا رَبِّ وَقَدْ أَعْطَيْتَنَا مَا لَمْ تُعْطِ أَحَدًا مِنْ خَلْقِكَ فَيَقُولُ أَلاَ أُعْطِيكُمْ أَفْضَلَ مِنْ ذَلِكَ فَيَقُولُونَ يَا رَبِّ وَأَىُّ شَىْءٍ أَفْضَلُ مِنْ ذَلِكَ فَيَقُولُ أُحِلُّ عَلَيْكُمْ رِضْوَانِي فَلاَ أَسْخَطُ عَلَيْكُمْ بَعْدَهُ أَبَدًا ‏"‏ ‏.‏\hadithno{7140}\hadithtrans{Abu Sa'id al-Khudri reported that Allah's Apostle (ﷺ) said that Allah would say to the inmates of Paradise:O, Dwellers of Paradise, and they would say in response: At thy service and pleasure, our Lord, the good is in Thy Hand. He (the Lord) would say: Are you well pleased now? They would say: Why should we not be pleased, O Lord, when Thou hast given us what Thou hast not given to any of Thy creatures? He would, however, say: May I not give you (something) even more excellent than that? And they would say: O Lord, what thing can be more excellent than this? And He would say: I shall cause My pleasure to alight upon you and I shall never be afterwards annoyed with you}}
\hadithdefcmd{muslim}{7142}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ لَيَتَرَاءَوْنَ الْغُرْفَةَ فِي الْجَنَّةِ كَمَا تَرَاءَوْنَ الْكَوْكَبَ فِي السَّمَاءِ ‏"‏ ‏.‏ قَالَ فَحَدَّثْتُ بِذَلِكَ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، فَقَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كَمَا تَرَاءَوْنَ الْكَوْكَبَ الدُّرِّيَّ فِي الأُفُقِ الشَّرْقِيِّ أَوِ الْغَرْبِيِّ ‏"‏ ‏.‏\hadithno{7142}\hadithtrans{Sahl b. Sa'd reported Allah's Messenger (ﷺ) as saying:The inmates of Paradise will look to the upper apartment of Paradise as you see the planets in the sky. I narrated this hadith to Nu'man b. Abi 'Ayyash and he said: I heard Abu Sa'id al-Khudri as saying: As you see the shining planets in the eastern and western (sides of) horizon}}
\hadithdefcmd{muslim}{7143}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرِ بْنِ يَحْيَى بْنِ خَالِدٍ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ لَيَتَرَاءَوْنَ أَهْلَ الْغُرَفِ مِنْ فَوْقِهِمْ كَمَا تَتَرَاءَوْنَ الْكَوْكَبَ الدُّرِّيَّ الْغَابِرَ مِنَ الأُفُقِ مِنَ الْمَشْرِقِ أَوِ الْمَغْرِبِ لِتَفَاضُلِ مَا بَيْنَهُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ تِلْكَ مَنَازِلُ الأَنْبِيَاءِ لاَ يَبْلُغُهَا غَيْرُهُمْ ‏.‏ قَالَ ‏"‏ بَلَى وَالَّذِي نَفْسِي بِيَدِهِ رِجَالٌ آمَنُوا بِاللَّهِ وَصَدَّقُوا الْمُرْسَلِينَ ‏"‏ ‏.‏\hadithno{7143}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:The inmates of Paradise would see the inmates of the apartment over them just as you see the shining planets which remain in the eastern and the western horizon because of the superiority some have over others. They said: Allah's Messenger, would in these abodes of Apostles others besides them not be able to reach? He said: Yes, they will, by Him, in Whose hand is my life, those who believe in God and acknowledge the Truth, will reach them}}
\hadithdefcmd{muslim}{7145}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ أَشَدِّ أُمَّتِي لِي حُبًّا نَاسٌ يَكُونُونَ بَعْدِي يَوَدُّ أَحَدُهُمْ لَوْ رَآنِي بِأَهْلِهِ وَمَالِهِ ‏"‏ ‏.‏\hadithno{7145}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The people most loved by me from amongst my Ummah would be those who would come after me but everyone amongst them would have the keenest desire to catch a glimpse of me even at the cost of his family and wealth}}
\hadithdefcmd{muslim}{7146}{حَدَّثَنَا أَبُو عُثْمَانَ، سَعِيدُ بْنُ عَبْدِ الْجَبَّارِ الْبَصْرِيُّ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، الْبُنَانِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَسُوقًا يَأْتُونَهَا كُلَّ جُمُعَةٍ فَتَهُبُّ رِيحُ الشَّمَالِ فَتَحْثُو فِي وُجُوهِهِمْ وَثِيَابِهِمْ فَيَزْدَادُونَ حُسْنًا وَجَمَالاً فَيَرْجِعُونَ إِلَى أَهْلِيهِمْ وَقَدِ ازْدَادُوا حُسْنًا وَجَمَالاً فَيَقُولُ لَهُمْ أَهْلُوهُمْ وَاللَّهِ لَقَدِ ازْدَدْتُمْ بَعْدَنَا حُسْنًا وَجَمَالاً ‏.‏ فَيَقُولُونَ وَأَنْتُمْ وَاللَّهِ لَقَدِ ازْدَدْتُمْ بَعْدَنَا حُسْنًا وَجَمَالاً ‏"‏ ‏.‏\hadithno{7146}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:In Paradise there is a street to which they would come every Friday. The north wind will blow and would scatter fragrance on their faces and on their clothes and would add to their beauty and loveliness, and then they would go back to their family after having an added lustre to their beauty and loveliness, and their family would say to them: By Allah, you have been increased in beauty and loveliness after leaving us, and they would say: By Allah, you have also increased in beauty and loveliness after us}}
\hadithdefcmd{muslim}{7147}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لِيَعْقُوبَ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، قَالَ إِمَّا تَفَاخَرُوا وَإِمَّا تَذَاكَرُوا الرِّجَالُ فِي الْجَنَّةِ أَكْثَرُ أَمِ النِّسَاءُ فَقَالَ أَبُو هُرَيْرَةَ أَوَلَمْ يَقُلْ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَوَّلَ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ وَالَّتِي تَلِيهَا عَلَى أَضْوَإِ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ لِكُلِّ امْرِئٍ مِنْهُمْ زَوْجَتَانِ اثْنَتَانِ يُرَى مُخُّ سُوقِهِمَا مِنْ وَرَاءِ اللَّحْمِ وَمَا فِي الْجَنَّةِ أَعْزَبُ ‏"‏ ‏.‏\hadithno{7147}\hadithtrans{Muhammad reported that some (persons) stated with a sense of pride and some discussed whether there would be more men in Paradise or more women. It was upon this that Abu Huraira reported that Abu'l Qasim (the Holy Prophet) (ﷺ) said:The (members) of the first group to get into Paradise would have their faces as bright as full moon during the night, and the next to this group would have their faces as bright as the shining stars in the sky, and every person would have two wives and the marrow of their shanks would glimmer beneath the flesh and there would be none without a wife in Paradise}}
\hadithdefcmd{muslim}{7148}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، قَالَ اخْتَصَمَ الرِّجَالُ وَالنِّسَاءُ أَيُّهُمْ فِي الْجَنَّةِ أَكْثَرُ فَسَأَلُوا أَبَا هُرَيْرَةَ فَقَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{7148}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7149}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - عَنْ عُمَارَةَ بْنِ، الْقَعْقَاعِ حَدَّثَنَا أَبُو زُرْعَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوَّلُ مَنْ يَدْخُلُ الْجَنَّةَ ‏"‏ ‏.‏ ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَوَّلَ زُمْرَةٍ يَدْخُلُونَ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ وَالَّذِينَ يَلُونَهُمْ عَلَى أَشَدِّ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ إِضَاءَةً لاَ يَبُولُونَ وَلاَ يَتَغَوَّطُونَ وَلاَ يَمْتَخِطُونَ وَلاَ يَتْفُلُونَ أَمْشَاطُهُمُ الذَّهَبُ وَرَشْحُهُمُ الْمِسْكُ وَمَجَامِرُهُمُ الأَلُوَّةُ وَأَزْوَاجُهُمُ الْحُورُ الْعِينُ أَخْلاَقُهُمْ عَلَى خُلُقِ رَجُلٍ وَاحِدٍ عَلَى صُورَةِ أَبِيهِمْ آدَمَ سِتُّونَ ذِرَاعًا فِي السَّمَاءِ ‏"‏ ‏.‏\hadithno{7149}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters that Allah's Messenger (ﷺ) said:The (members of the) first group which would get into Paradise will have their faces as bright as stars in the sky. They would neither pass water, nor void excrement, nor will they suffer from catarrh, nor will they spit, and their combs would be made of gold, and their sweat will be musk, the fuel of their brazier will be aloes, and their wives will be large-eyed maidens and their form would be alike as one single person after the form of their father (Adam) sixty cubits tall}}
\hadithdefcmd{muslim}{7150}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِي عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ثُمَّ الَّذِينَ يَلُونَهُمْ عَلَى أَشَدِّ نَجْمٍ فِي السَّمَاءِ إِضَاءَةً ثُمَّ هُمْ بَعْدَ ذَلِكَ مَنَازِلُ لاَ يَتَغَوَّطُونَ وَلاَ يَبُولُونَ وَلاَ يَمْتَخِطُونَ وَلاَ يَبْزُقُونَ أَمْشَاطُهُمُ الذَّهَبُ وَمَجَامِرُهُمُ الأَلُوَّةُ وَرَشْحُهُمُ الْمِسْكُ أَخْلاَقُهُمْ عَلَى خُلُقِ رَجُلٍ وَاحِدٍ عَلَى طُولِ أَبِيهِمْ آدَمَ سِتُّونَ ذِرَاعًا ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي شَيْبَةَ عَلَى خُلُقِ رَجُلٍ ‏.‏ وَقَالَ أَبُو كُرَيْبٍ عَلَى خَلْقِ رَجُلٍ ‏.‏ وَقَالَ ابْنُ أَبِي شَيْبَةَ عَلَى صُورَةِ أَبِيهِمْ ‏.‏\hadithno{7150}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The first group of my Ummah to get into Paradise would be like a full moon in the night. Then those who would be next to them; they would be like the most significantly glittering stars in regard to brightness, then after them (others) in ranks. They would neither void excrement, nor pass water, nor suffer from catarrh, nor would they spit. And their combs would be made of gold, and the fuel of their braziers would be aloes and their sweat would be musk and their form would be the form of one single person according to the length of their father sixty cubits tall. This hadith has been transmitted on the authority of Ibn Abi Shaiba with a slight variation of wording}}
\hadithdefcmd{muslim}{7151}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ زُمْرَةٍ تَلِجُ الْجَنَّةَ صُوَرُهُمْ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ لاَ يَبْصُقُونَ فِيهَا وَلاَ يَمْتَخِطُونَ وَلاَ يَتَغَوَّطُونَ فِيهَا آنِيَتُهُمْ وَأَمْشَاطُهُمْ مِنَ الذَّهَبِ وَالْفِضَّةِ وَمَجَامِرُهُمْ مِنَ الأَلُوَّةِ وَرَشْحُهُمُ الْمِسْكُ وَلِكُلِّ وَاحِدٍ مِنْهُمْ زَوْجَتَانِ يُرَى مُخُّ سَاقِهِمَا مِنْ وَرَاءِ اللَّحْمِ مِنَ الْحُسْنِ لاَ اخْتِلاَفَ بَيْنَهُمْ وَلاَ تَبَاغُضَ قُلُوبُهُمْ قَلْبٌ وَاحِدٌ يُسَبِّحُونَ اللَّهَ بُكْرَةً وَعَشِيًّا ‏"‏ ‏.‏\hadithno{7151}\hadithtrans{Hammam b. Munabbih reported:These are some of the ahidith which Abu Huraira reported from Allah's Messenger (ﷺ) and one is this that he is reported to have said: The (members of the) first group that would be admitted to Paradise would have their faces as bright as full moon during the night. They would neither spit nor suffer catarrh, nor void excrement. They would have their utensils and their combs made of gold and silver and the fuel of their braziers would be aloes and their sweat would be musk and every one of them would have two spouses (so beautiful) that the marrow of their shanks would be visible through the flesh. There would be no dissension amongst them and no enmity in their hearts. Their hearts would be like one heart, glorifying Allah morning and evening}}
\hadithdefcmd{muslim}{7152}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ عُثْمَانُ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ يَأْكُلُونَ فِيهَا وَيَشْرَبُونَ وَلاَ يَتْفُلُونَ وَلاَ يَبُولُونَ وَلاَ يَتَغَوَّطُونَ وَلاَ يَمْتَخِطُونَ ‏"‏ ‏.‏ قَالُوا فَمَا بَالُ الطَّعَامِ قَالَ ‏"‏ جُشَاءٌ وَرَشْحٌ كَرَشْحِ الْمِسْكِ يُلْهَمُونَ التَّسْبِيحَ وَالتَّحْمِيدَ كَمَا يُلْهَمُونَ النَّفَسَ ‏"‏ ‏.‏\hadithno{7152}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) as saying that the inmates of Paradise would eat and drink but would neither spit, nor pass water, nor void excrement, nor suffer catarrah. It was said: Then, what would happen with food? Thereupon he said: They would belch and sweat (and it would be over with their food), and their sweat would be that of musk and they would glorify and praise Allah as easily as you breathe}}
\hadithdefcmd{muslim}{7153}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ ‏ "‏ كَرَشْحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{7153}\hadithtrans{This hadith has been transmitted on the authority of A'mash with a slight variation of wording}}
\hadithdefcmd{muslim}{7154}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَحَجَّاجُ بْنُ الشَّاعِرِ، كِلاَهُمَا عَنْ أَبِي عَاصِمٍ، - قَالَ حَسَنٌ حَدَّثَنَا أَبُو عَاصِمٍ، - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ، عَبْدِ اللَّهِ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَأْكُلُ أَهْلُ الْجَنَّةِ فِيهَا وَيَشْرَبُونَ وَلاَ يَتَغَوَّطُونَ وَلاَ يَمْتَخِطُونَ وَلاَ يَبُولُونَ وَلَكِنْ طَعَامُهُمْ ذَاكَ جُشَاءٌ كَرَشْحِ الْمِسْكِ يُلْهَمُونَ التَّسْبِيحَ وَالْحَمْدَ كَمَا يُلْهَمُونَ النَّفَسَ ‏"‏ ‏.‏ قَالَ وَفِي حَدِيثِ حَجَّاجٍ ‏"‏ طَعَامُهُمْ ذَلِكَ ‏"‏ ‏.‏\hadithno{7154}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) said that the inmates of Paradise would eat therein and they would also drink, but they would neither void excrement, nor suffer catarrh, nor pass water, and their eating (would be digested) in the form of belching and their sweat would be musk aged they would glorify and praise Allah as easily ai you breathe}}
\hadithdefcmd{muslim}{7155}{وَحَدَّثَنِي سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَيُلْهَمُونَ التَّسْبِيحَ وَالتَّكْبِيرَ كَمَا يُلْهَمُونَ النَّفَسَ ‏"‏ ‏.‏\hadithno{7155}\hadithtrans{This hadith has been transmitted on the authority of Jabir with a slight variation of wording}}
\hadithdefcmd{muslim}{7156}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يَدْخُلُ الْجَنَّةَ يَنْعَمُ لاَ يَبْأَسُ لاَ تَبْلَى ثِيَابُهُ وَلاَ يَفْنَى شَبَابُهُ ‏"‏ ‏.‏\hadithno{7156}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:He who would get into Paradise (would be made to enjoy such an everlasting) bliss that he would neither become destitute, nor would his clothes wear out, nor his youth would decline}}
\hadithdefcmd{muslim}{7157}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لإِسْحَاقَ - قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ قَالَ الثَّوْرِيُّ فَحَدَّثَنِي أَبُو إِسْحَاقَ، أَنَّ الأَغَرَّ، حَدَّثَهُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُنَادِي مُنَادٍ إِنَّ لَكُمْ أَنْ تَصِحُّوا فَلاَ تَسْقَمُوا أَبَدًا وَإِنَّ لَكُمْ أَنْ تَحْيَوْا فَلاَ تَمُوتُوا أَبَدًا وَإِنَّ لَكُمْ أَنْ تَشِبُّوا فَلاَ تَهْرَمُوا أَبَدًا وَإِنَّ لَكُمْ أَنْ تَنْعَمُوا فَلاَ تَبْتَئِسُوا أَبَدًا ‏"‏ ‏.‏ فَذَلِكَ قَوْلُهُ عَزَّ وَجَلَّ ‏\{‏ وَنُودُوا أَنْ تِلْكُمُ الْجَنَّةُ أُورِثْتُمُوهَا بِمَا كُنْتُمْ تَعْمَلُونَ‏\}‏\hadithno{7157}\hadithtrans{Abu Sa'id al-Khudri and Abu Huraira both reported Allah's Messenger (ﷺ) as saying:There would be an announcer (in Paradise) who would make this announcement: Verily I there is in store for you (everlasting) health and that you should never fall ill and that you live (for ever) and do not die at all. And that you would remain young and never grow old. And that you would always live in affluent circumstances and never become destitute, as words of Allah, the Exalted and Glorious, are:" And it would be announced to them: This is the Paradise. You have been made to inherit it for what you used to do". (VII;)}}
\hadithdefcmd{muslim}{7158}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، عَنْ أَبِي قُدَامَةَ، - وَهُوَ الْحَارِثُ بْنُ عُبَيْدٍ - عَنْ أَبِي، عِمْرَانَ الْجَوْنِيِّ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلْمُؤْمِنِ فِي الْجَنَّةِ لَخَيْمَةً مِنْ لُؤْلُؤَةٍ وَاحِدَةٍ مُجَوَّفَةٍ طُولُهَا سِتُّونَ مِيلاً لِلْمُؤْمِنِ فِيهَا أَهْلُونَ يَطُوفُ عَلَيْهِمُ الْمُؤْمِنُ فَلاَ يَرَى بَعْضُهُمْ بَعْضًا ‏"‏ ‏.‏\hadithno{7158}\hadithtrans{Abu Bakr b. Abdullah b. Qais reported on the authority of his father that Allah's Messenger (ﷺ) said that in Paradise there would be for a believer a tent of a single hollowed pearl the breadth of which would be sixty miles. It would be meant for a believer and the believers would go around it and none would be able to see the others}}
\hadithdefcmd{muslim}{7159}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْجَنَّةِ خَيْمَةٌ مِنْ لُؤْلُؤَةٍ مُجَوَّفَةٍ عَرْضُهَا سِتُّونَ مِيلاً فِي كُلِّ زَاوِيَةٍ مِنْهَا أَهْلٌ مَا يَرَوْنَ الآخَرِينَ يَطُوفُ عَلَيْهِمُ الْمُؤْمِنُ ‏"‏ ‏.‏\hadithno{7159}\hadithtrans{Abu Bakr b. Abdullah b. Qais reported on the authority of his father that Allah's Messenger (ﷺ) said that in Paradise there would be a tent made of a single hollowed pearl, the breadth of which would be sixty miles from all sides and there would live a family in each corner and the other would not be able to see the believer who goes around them}}
\hadithdefcmd{muslim}{7160}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هَمَّامٌ، عَنْ أَبِي، عِمْرَانَ الْجَوْنِيِّ عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى بْنِ قَيْسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْمَةُ دُرَّةٌ طُولُهَا فِي السَّمَاءِ سِتُّونَ مِيلاً فِي كُلِّ زَاوِيَةٍ مِنْهَا أَهْلٌ لِلْمُؤْمِنِ لاَ يَرَاهُمُ الآخَرُونَ ‏"‏ ‏.‏\hadithno{7160}\hadithtrans{This hadith has been transmitted on the authority of Abu Bakr b. Abu Musa b. Qais who, on the authority of his father, reported the Apostle (ﷺ) to have said that there would be a tent made of a pearl whose height towards the sky would be sixty miles. In each corner, there would be a family of the believer, out of sight for the others}}
\hadithdefcmd{muslim}{7161}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَعَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَيْحَانُ وَجَيْحَانُ وَالْفُرَاتُ وَالنِّيلُ كُلٌّ مِنْ أَنْهَارِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{7161}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Saihan, Jaihan, Euphrates and Nile are all among the rivers of Paradise}}
\hadithdefcmd{muslim}{7162}{حَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ اللَّيْثِيُّ حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَدْخُلُ الْجَنَّةَ أَقْوَامٌ أَفْئِدَتُهُمْ مِثْلُ أَفْئِدَةِ الطَّيْرِ ‏"‏ ‏.‏\hadithno{7162}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There would enter Paradise people whose hearts would be like those of the hearts of birds}}
\hadithdefcmd{muslim}{7163}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا بِهِ أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَلَقَ اللَّهُ عَزَّ وَجَلَّ آدَمَ عَلَى صُورَتِهِ طُولُهُ سِتُّونَ ذِرَاعًا فَلَمَّا خَلَقَهُ قَالَ اذْهَبْ فَسَلِّمْ عَلَى أُولَئِكَ النَّفَرِ وَهُمْ نَفَرٌ مِنَ الْمَلاَئِكَةِ جُلُوسٌ فَاسْتَمِعْ مَا يُجِيبُونَكَ فَإِنَّهَا تَحِيَّتُكَ وَتَحِيَّةُ ذُرِّيَّتِكَ قَالَ فَذَهَبَ فَقَالَ السَّلاَمُ عَلَيْكُمْ فَقَالُوا السَّلاَمُ عَلَيْكَ وَرَحْمَةُ اللَّهِ - قَالَ - فَزَادُوهُ وَرَحْمَةُ اللَّهِ - قَالَ - فَكُلُّ مَنْ يَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ آدَمَ وَطُولُهُ سِتُّونَ ذِرَاعًا فَلَمْ يَزَلِ الْخَلْقُ يَنْقُصُ بَعْدَهُ حَتَّى الآنَ ‏"‏ ‏.‏\hadithno{7163}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, created Adam in His image with His length of sixty cubits, and as He created him He told him to greet that group, and that was a party of angels sitting there, and listen to the response that they give him, for it would form his greeting and that of his offspring. He then went away and said: Peace be upon you! They (the angels) said: May there be peace upon you and the Mercy of Allah, and they made an addition of" Mercy of Allah". So he who would get into Paradise would get in the form of Adam, his length being sixty cubits, then the people who followed him continued to diminish in size up to this day}}
\hadithdefcmd{muslim}{7164}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الْعَلاَءِ بْنِ خَالِدٍ الْكَاهِلِيِّ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُؤْتَى بِجَهَنَّمَ يَوْمَئِذٍ لَهَا سَبْعُونَ أَلْفَ زِمَامٍ مَعَ كُلِّ زِمَامٍ سَبْعُونَ أَلْفَ مَلَكٍ يَجُرُّونَهَا ‏"‏ ‏.‏\hadithno{7164}\hadithtrans{Abdullah b. Mas`ud reported Allah's Messenger (ﷺ) as saying:Hell would be brought on that day (the Day of Judgment) with seventy thousand bridles, and seventy thousand angels dragging each bridle}}
\hadithdefcmd{muslim}{7165}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ نَارُكُمْ هَذِهِ الَّتِي يُوقِدُ ابْنُ آدَمَ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنْ حَرِّ جَهَنَّمَ ‏"‏ ‏.‏ قَالُوا وَاللَّهِ إِنْ كَانَتْ لَكَافِيَةً يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّهَا فُضِّلَتْ عَلَيْهَا بِتِسْعَةٍ وَسِتِّينَ جُزْءًا كُلُّهَا مِثْلُ حَرِّهَا ‏"‏ ‏.‏\hadithno{7165}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The fire which sons of Adam burn is only one-seventieth part of the Fire of Hell. His Companions said: By Allah, even ordinary fire would have been enough (to burn people). Thereupon he said: It is sixty-nine parts in excess of (the heat of) fire in this world each of them being equivalent to their heat}}
\hadithdefcmd{muslim}{7166}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي الزِّنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ كُلُّهُنَّ مِثْلُ حَرِّهَا ‏"‏ ‏.‏\hadithno{7166}\hadithtrans{This hadith has been narrated on the authority of Abn Huraira through another chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{7167}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي، حَازِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ سَمِعَ وَجْبَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَدْرُونَ مَا هَذَا ‏"‏ ‏.‏ قَالَ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ هَذَا حَجَرٌ رُمِيَ بِهِ فِي النَّارِ مُنْذُ سَبْعِينَ خَرِيفًا فَهُوَ يَهْوِي فِي النَّارِ الآنَ حَتَّى انْتَهَى إِلَى قَعْرِهَا ‏"‏ ‏.‏\hadithno{7167}\hadithtrans{Abu Huraira reported:We were in the company of Allah's Messenger (ﷺ) that we heard a terrible sound. Thereupon Allah's Apostle (ﷺ) said: Do you know what (sound) is this? We said: Allah and His Messenger know best. Thereupon he said: That is a stone which was thrown seventy years before in Hell and it has'been constantly slipping down and now it has reached its base}}
\hadithdefcmd{muslim}{7168}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا مَرْوَانُ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ هَذَا وَقَعَ فِي أَسْفَلِهَا فَسَمِعْتُمْ وَجْبَتَهَا ‏"‏ ‏.‏\hadithno{7168}\hadithtrans{This hadith has been narrated on the authority of Abfi Huraira with the same chain of transmitters but with this change of wording that the Prophet (may. peace be upon him) said:It reached at its base and you heard its sound}}
\hadithdefcmd{muslim}{7169}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ قَالَ قَتَادَةُ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ سَمُرَةَ، أَنَّهُ سَمِعَ نَبِيَّ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مِنْهُمْ مَنْ تَأْخُذُهُ النَّارُ إِلَى كَعْبَيْهِ وَمِنْهُمْ مَنْ تَأْخُذُهُ إِلَى حُجْزَتِهِ وَمِنْهُمْ مَنْ تَأْخُذُهُ إِلَى عُنُقِهِ ‏"‏ ‏.‏\hadithno{7169}\hadithtrans{Samura b. Jundub reported Allah's Apostle (may peace -be upon him) as saying:There will be some to whose ankels the fire will reach, some to whose knees, some to whose waist the fire will reach, and some to whose collar-bone the fire will reach}}
\hadithdefcmd{muslim}{7170}{حَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَطَاءٍ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْهُمْ مَنْ تَأْخُذُهُ النَّارُ إِلَى كَعْبَيْهِ وَمِنْهُمْ مَنْ تَأْخُذُهُ النَّارُ إِلَى رُكْبَتَيْهِ وَمِنْهُمْ مَنْ تَأْخُذُهُ النَّارُ إِلَى حُجْزَتِهِ وَمِنْهُمْ مَنْ تَأْخُذُهُ النَّارُ إِلَى تَرْقُوَتِهِ ‏"‏ ‏.‏\hadithno{7170}\hadithtrans{Samura b. Jundub reported Allah's Messenger (ﷺ) as saying:There would be among them those to whom the fire will reach up to their ankels and to some of them the fire would reach their knees and to some it would reach their waists and to some it would reach up to their collar-bones}}
\hadithdefcmd{muslim}{7171}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا رَوْحٌ، حَدَّثَنَا سَعِيدٌ، بِهَذَا الإِسْنَادِ وَجَعَلَ مَكَانَ حُجْزَتِهِ حَقْوَيْهِ ‏.‏\hadithno{7171}\hadithtrans{This hadith has been narrated on the authority of Sa'id with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7172}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ احْتَجَّتِ النَّارُ وَالْجَنَّةُ فَقَالَتْ هَذِهِ يَدْخُلُنِي الْجَبَّارُونَ وَالْمُتَكَبِّرُونَ ‏.‏ وَقَالَتْ هَذِهِ يَدْخُلُنِي الضُّعَفَاءُ وَالْمَسَاكِينُ فَقَالَ اللَّهُ عَزَّ وَجَلَّ لِهَذِهِ أَنْتِ عَذَابِي أُعَذِّبُ بِكِ مَنْ أَشَاءُ - وَرُبَّمَا قَالَ أُصِيبُ بِكِ مَنْ أَشَاءُ - وَقَالَ لِهَذِهِ أَنْتِ رَحْمَتِي أَرْحَمُ بِكِ مَنْ أَشَاءُ وَلِكُلِّ وَاحِدَةٍ مِنْكُمَا مِلْؤُهَا ‏"‏ ‏.‏\hadithno{7172}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:There was a dispute between the Hell and the Paradise and it (the Hell) said: The haughty and the proud would find abode in me. And the Paradise said: The meek and the humble would find their abode in me. Thereupon Allah, the Exalted and Glorious, (addressing the Hell) said: You are (the means) of My punishment by which I punish those of My servants whom I wish. (And addressing the Paradise) He said: You are only My Mercy by means of which 1 shall show mercy to those whom I wish, but each one of you would be full}}
\hadithdefcmd{muslim}{7173}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَحَاجَّتِ النَّارُ وَالْجَنَّةُ فَقَالَتِ النَّارُ أُوثِرْتُ بِالْمُتَكَبِّرِينَ وَالْمُتَجَبِّرِينَ ‏.‏ وَقَالَتِ الْجَنَّةُ فَمَا لِي لاَ يَدْخُلُنِي إِلاَّ ضُعَفَاءُ النَّاسِ وَسَقَطُهُمْ وَعَجَزُهُمْ ‏.‏ فَقَالَ اللَّهُ لِلْجَنَّةِ أَنْتِ رَحْمَتِي أَرْحَمُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي ‏.‏ وَقَالَ لِلنَّارِ أَنْتِ عَذَابِي أُعَذِّبُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي وَلِكُلِّ وَاحِدَةٍ مِنْكُمْ مِلْؤُهَا فَأَمَّا النَّارُ فَلاَ تَمْتَلِئُ ‏.‏ فَيَضَعُ قَدَمَهُ عَلَيْهَا فَتَقُولُ قَطْ قَطْ ‏.‏ فَهُنَالِكَ تَمْتَلِئُ وَيُزْوَى بَعْضُهَا إِلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{7173}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:The Hell and the Paradise fell into dispute and the Hell said: I have been dis- tinguished by the proud and the haughty. And the Paradise said: What is the matter with me that the meek and the humble amongst people and the downtrodden and the simple enter me? Thereupon Allah said to the Paradise: You are (the means) of My Mercy whereby I show mercy to those of My servants whom 1 wish, and He said to the Hell: You are (the means) of punishment whereby 1 punish those of My servants whoml wish. Both of you will be full. The Hell will riot be filled up until Allah puts down His foot in it. The Hell would say: Enough, enough, enough, and at that time it will be filled up, all its parts integrated together}}
\hadithdefcmd{muslim}{7174}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ الْهِلاَلِيُّ، حَدَّثَنَا أَبُو سُفْيَانَ، - يَعْنِي مُحَمَّدَ بْنَ حُمَيْدٍ - عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ احْتَجَّتِ الْجَنَّةُ وَالنَّارُ ‏"‏ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمَعْنَى حَدِيثِ أَبِي الزِّنَادِ ‏.‏\hadithno{7174}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The Paradise and the Hell disputed with each other. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7175}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَحَاجَّتِ الْجَنَّةُ وَالنَّارُ فَقَالَتِ النَّارُ أُوثِرْتُ بِالْمُتَكَبِّرِينَ وَالْمُتَجَبِّرِينَ ‏.‏ وَقَالَتِ الْجَنَّةُ فَمَا لِي لاَ يَدْخُلُنِي إِلاَّ ضُعَفَاءُ النَّاسِ وَسَقَطُهُمْ وَغِرَّتُهُمْ قَالَ اللَّهُ لِلْجَنَّةِ إِنَّمَا أَنْتِ رَحْمَتِي أَرْحَمُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي ‏.‏ وَقَالَ لِلنَّارِ إِنَّمَا أَنْتِ عَذَابِي أُعَذِّبُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي ‏.‏ وَلِكُلِّ وَاحِدَةٍ مِنْكُمَا مِلْؤُهَا فَأَمَّا النَّارُ فَلاَ تَمْتَلِئُ حَتَّى يَضَعَ اللَّهُ تَبَارَكَ وَتَعَالَى رِجْلَهُ تَقُولُ قَطْ قَطْ قَطْ ‏.‏ فَهُنَالِكَ تَمْتَلِئُ وَيُزْوَى بَعْضُهَا إِلَى بَعْضٍ وَلاَ يَظْلِمُ اللَّهُ مِنْ خَلْقِهِ أَحَدًا وَأَمَّا الْجَنَّةُ فَإِنَّ اللَّهَ يُنْشِئُ لَهَا خَلْقًا ‏"‏ ‏.‏\hadithno{7175}\hadithtrans{Hammam b. Munabbih reported that Abu Huraira narrated to them some ahadith of Allah's Messenger (ﷺ) and one of them is this that Allah's Messenger (ﷺ) said:The Paradise and the Hell fell into dispute and the Hell said: 1 have been distinguished for accommodating (the haughty and proud in me), and the Paradise said: What is the matter that the meek and the humble and the downtrodden and simple would find an abode in me? Thereupon Allah said to Paradise: You are a (means) of My Mercy. 1 shall show mercy through you to one whom I will from amongst My servants. And lie said to the Hell: You are a (sign) of My chastisement and I shall chastise through you anyone whom I will from amongst My servants and both of you, would be full. And as regards the Hell it would not be full until Allah, the Exalted and Glorious, places His foot therein, and it would say: Enough, enough, enough, and it would be then full and the one part would draw very close to the other one and Allah would not treat unjustly anyone amongst His creation and He would create another creation for the Paradise (to accommodate it)}}
\hadithdefcmd{muslim}{7176}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجَّتِ الْجَنَّةُ وَالنَّارُ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ أَبِي هُرَيْرَةَ إِلَى قَوْلِهِ ‏"‏ وَلِكِلَيْكُمَا عَلَىَّ مِلْؤُهَا ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ مِنَ الزِّيَادَةِ ‏.‏\hadithno{7176}\hadithtrans{Abu Sa'id al-Khudri reported that Allah's Messenger (ﷺ) said:The Paradise and the Hell disputed with each other. The rest of the hadith is the same as transmitted by Abu Huraira up to the words'." It is essential for Me to fill up both of you}}
\hadithdefcmd{muslim}{7177}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَزَالُ جَهَنَّمُ تَقُولُ هَلْ مِنْ مَزِيدٍ ‏.‏ حَتَّى يَضَعَ فِيهَا رَبُّ الْعِزَّةِ تَبَارَكَ وَتَعَالَى قَدَمَهُ فَتَقُولُ قَطْ قَطْ وَعِزَّتِكَ ‏.‏ وَيُزْوَى بَعْضُهَا إِلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{7177}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) said that the Hell would continue to say:Is there anything more, until Allah, the Exalted and High, would place His foot therein and that would say: Enough, enough, by Your Honour, and some parts of it would draw close to the other}}
\hadithdefcmd{muslim}{7178}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، الْعَطَّارِ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ شَيْبَانَ ‏.‏\hadithno{7178}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{7179}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ يَوْمَ نَقُولُ لِجَهَنَّمَ هَلِ امْتَلأْتِ وَتَقُولُ هَلْ مِنْ مَزِيدٍ‏\}‏ فَأَخْبَرَنَا عَنْ سَعِيدٍ عَنْ قَتَادَةَ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ تَزَالُ جَهَنَّمُ يُلْقَى فِيهَا وَتَقُولُ هَلْ مِنْ مَزِيدٍ حَتَّى يَضَعَ رَبُّ الْعِزَّةِ فِيهَا قَدَمَهُ فَيَنْزَوِي بَعْضُهَا إِلَى بَعْضٍ وَتَقُولُ قَطْ قَطْ بِعِزَّتِكَ وَكَرَمِكَ ‏.‏ وَلاَ يَزَالُ فِي الْجَنَّةِ فَضْلٌ حَتَّى يُنْشِئَ اللَّهُ لَهَا خَلْقًا فَيُسْكِنَهُمْ فَضْلَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{7179}\hadithtrans{Abd al-Wahhab b. Ata' reported in connection with the words of Allah, the Exalted and the Glorious:We would say to Hell on the Day of Ressurection: Have you been completely filled up? and it would say: Is there anything -more? And he stated on the authority of Anas b. Malik that Allah's Apostle (ﷺ) said: (The sinners) would be thrown therein and it would continue to say: Is there anything more, until Allah, the Exalted and Glorious, would keep His foot there- in and some of its part would draw close to the other and it would say: Enough, enough, by Thy Honour and by Thy Dignity, and there would be enough space in Paradise until Allah would create a new creation and He would make them accommo- date that spare place in Paradise}}
\hadithdefcmd{muslim}{7180}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - أَخْبَرَنَا ثَابِتٌ، قَالَ سَمِعْتُ أَنسًا، يَقُولُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَبْقَى مِنَ الْجَنَّةِ مَا شَاءَ اللَّهُ أَنْ يَبْقَى ثُمَّ يُنْشِئُ اللَّهُ تَعَالَى لَهَا خَلْقًا مِمَّا يَشَاءُ ‏"‏ ‏.‏\hadithno{7180}\hadithtrans{Anas reported Allah's Apostle (ﷺ) as saying:There would be left some space in Paradise as Allah would like that to be left. Then Allah would create another creation as He would like}}
\hadithdefcmd{muslim}{7181}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُجَاءُ بِالْمَوْتِ يَوْمَ الْقِيَامَةِ كَأَنَّهُ كَبْشٌ أَمْلَحُ - زَادَ أَبُو كُرَيْبٍ - فَيُوقَفُ بَيْنَ الْجَنَّةِ وَالنَّارِ - وَاتَّفَقَا فِي بَاقِي الْحَدِيثِ - فَيُقَالُ يَا أَهْلَ الْجَنَّةِ هَلْ تَعْرِفُونَ هَذَا فَيَشْرَئِبُّونَ وَيَنْظُرُونَ وَيَقُولُونَ نَعَمْ هَذَا الْمَوْتُ - قَالَ - وَيُقَالُ يَا أَهْلَ النَّارِ هَلْ تَعْرِفُونَ هَذَا قَالَ فَيَشْرَئِبُّونَ وَيَنْظُرُونَ وَيَقُولُونَ نَعَمْ هَذَا الْمَوْتُ - قَالَ - فَيُؤْمَرُ بِهِ فَيُذْبَحُ - قَالَ - ثُمَّ يُقَالُ يَا أَهْلَ الْجَنَّةِ خُلُودٌ فَلاَ مَوْتَ وَيَا أَهْلَ النَّارِ خُلُودٌ فَلاَ مَوْتَ ‏"‏ ‏.‏ قَالَ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ وَأَنْذِرْهُمْ يَوْمَ الْحَسْرَةِ إِذْ قُضِيَ الأَمْرُ وَهُمْ فِي غَفْلَةٍ وَهُمْ لاَ يُؤْمِنُونَ‏\}‏ وَأَشَارَ بِيَدِهِ إِلَى الدُّنْيَا ‏.‏\hadithno{7181}\hadithtrans{Abu Sa'id reported Allah's Messenger (ﷺ) as saying:Death would be brought on the Day of Resurrection. in the form of a white-coloured ram. Abu Kuraib made this addition: Then it would be made to stand between the Paradise and the Hell. So far as the rest of the hadith is concerned there is perfect agreement (between the two narrators) and it would be said to the inmates of Paradise: Do you recognise this? They would raise up their necks and look towards it and say: Yes, ' it is death. Then it would be said to the inmates of Hell-Fire.. Do you recognise this? And they would raise up their necks and look and say: Yes, it is death. Then command would be given for slaughtering that and then it would be said: 0 inmates of Paradise,, there is an everlasting life for you and no death. And then (addressing) to the inmates of the Hell-Fire, it would be said: 0 inmates of Hell-Fire, there is an everlasting living for you and no death. Allah's Messenger (may peace be u@on him) then recited this verse pointing with his hand to this (material) world:" Warn them, this Day of dismay, and when their affairs would be decided and they would be un- mindful and they believe not" (xix)}}
\hadithdefcmd{muslim}{7182}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، سَعِيدٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أُدْخِلَ أَهْلُ الْجَنَّةِ الْجَنَّةَ وَأَهْلُ النَّارِ النَّارَ قِيلَ يَا أَهْلَ الْجَنَّةِ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمَعْنَى حَدِيثِ أَبِي مُعَاوِيَةَ غَيْرَ أَنَّهُ قَالَ ‏"‏ فَذَلِكَ قَوْلُهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرْ أَيْضًا وَأَشَارَ بِيَدِهِ إِلَى الدُّنْيَا ‏.‏\hadithno{7182}\hadithtrans{Abu Sa'id reported Allah's Messenger (ﷺ) as saying:When the inmates of Paradise would be admitted to Paradise and the inmates of Hell would be admitted to Hell, it would be said (to the inmates of Paradise): 0 inmates of Paradise. The rest of the hadith is the same but with this variation (that he only) said. That is the word of Allah, the Exalted. And he did not say: Then Allah's Mes- senger (ﷺ) recited, and he did not make a mention of his having pointed with his hand towards the (material) world}}
\hadithdefcmd{muslim}{7183}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، حَدَّثَنَا نَافِعٌ، أَنَّ عَبْدَ اللَّهِ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُدْخِلُ اللَّهُ أَهْلَ الْجَنَّةِ الْجَنَّةَ وَيُدْخِلُ أَهْلَ النَّارِ النَّارَ ثُمَّ يَقُومُ مُؤَذِّنٌ بَيْنَهُمْ فَيَقُولُ يَا أَهْلَ الْجَنَّةِ لاَ مَوْتَ وَيَا أَهْلَ النَّارِ لاَ مَوْتَ كُلٌّ خَالِدٌ فِيمَا هُوَ فِيهِ ‏"‏ ‏.‏\hadithno{7183}\hadithtrans{Abdullah reported that Allah's Messenger (ﷺ) said:Allah would admit the inmates of Paradise into Paradise and the inmates of Hell into Hell. Then the announcer would stand between them and say: 0 inmates of Paradise, there is no death for you,0 inmates of Hell, there is no death for you. You would live for ever therein}}
\hadithdefcmd{muslim}{7184}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ، عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَارَ أَهْلُ الْجَنَّةِ إِلَى الْجَنَّةِ وَصَارَ أَهْلُ النَّارِ إِلَى النَّارِ أُتِيَ بِالْمَوْتِ حَتَّى يُجْعَلَ بَيْنَ الْجَنَّةِ وَالنَّارِ ثُمَّ يُذْبَحُ ثُمَّ يُنَادِي مُنَادٍ يَا أَهْلَ الْجَنَّةِ لاَ مَوْتَ وَيَا أَهْلَ النَّارِ لاَ مَوْتَ ‏.‏ فَيَزْدَادُ أَهْلُ الْجَنَّةِ فَرَحًا إِلَى فَرَحِهِمْ وَيَزْدَادُ أَهْلُ النَّارِ حُزْنًا إِلَى حُزْنِهِمْ ‏"‏ ‏.‏\hadithno{7184}\hadithtrans{Umar b. Muhammad b. Zaid b. `Abdullah b. `Umar b. al-Khattab reported on the authority of his father `Abdullah b. `Umar that Allah's Messenger (ﷺ) said:When the inmates of Paradise would go to Paradise and the inmates of Hell would go to Hell, death would be called and it would be placed between the Paradise and the Hell and then slaughtered and then the announcer would announce: O inmates of Paradise, no death. O inmates of Hell-Fire, no death. And it would increase the delight of the inmates of Paradise and it would increase the grief of the inmates of Hell-Fire}}
\hadithdefcmd{muslim}{7185}{حَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ هَارُونَ بْنِ سَعْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ضِرْسُ الْكَافِرِ أَوْ نَابُ الْكَافِرِ مِثْلُ أُحُدٍ وَغِلَظُ جِلْدِهِ مَسِيرَةُ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{7185}\hadithtrans{It is transmitted on the authority of Abu Huraira that Allah's Messenger (ﷺ) said:The molar tooth of an unbeliever or the canine teeth of an unbeliever will be like Uhud and the thickness of his skin a three night's journey}}
\hadithdefcmd{muslim}{7186}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَحْمَدُ بْنُ عُمَرَ الْوَكِيعِيُّ، قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ قَالَ ‏"‏ مَا بَيْنَ مَنْكِبَىِ الْكَافِرِ فِي النَّارِ مَسِيرَةُ ثَلاَثَةِ أَيَّامٍ لِلرَّاكِبِ الْمُسْرِعِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الْوَكِيعِيُّ ‏"‏ فِي النَّارِ ‏"‏ ‏.‏\hadithno{7186}\hadithtrans{Abu Huraira reported directly from Allah's Messenger (ﷺ) that he said:The distance of the two shoulders of the non-believer in Hell will be a three-day journey for a swift rider}}
\hadithdefcmd{muslim}{7187}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي مَعْبَدُ بْنُ خَالِدٍ، أَنَّهُ سَمِعَ حَارِثَةَ بْنَ وَهْبٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ كُلُّ ضَعِيفٍ مُتَضَعَّفٍ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَهْلِ النَّارِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ كُلُّ عُتُلٍّ جَوَّاظٍ مُسْتَكْبِرٍ ‏"‏ ‏.‏\hadithno{7187}\hadithtrans{Haritha b. Wahb reported that he heard Allah's Apostle (ﷺ) as saying:May I not inform you about the inmates of Paradise? They said: Do this, of course. Thereupon Allah's Apostle (ﷺ) said: Every humble person who is considered to be humble if he were to adjure In the name of Allah, He would fulfil it. He then said: May I not inform you about the denizens of Hell-Fire? They said: Yes. And he said: Every haughty, fat and proud (person)}}
\hadithdefcmd{muslim}{7188}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ أَلاَ أَدُلُّكُمْ ‏"‏ ‏.‏\hadithno{7188}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7189}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ الْخُزَاعِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكُمْ بِأَهْلِ الْجَنَّةِ كُلُّ ضَعِيفٍ مُتَضَعَّفٍ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ أَلاَ أُخْبِرُكُمْ بِأَهْلِ النَّارِ كُلُّ جَوَّاظٍ زَنِيمٍ مُتَكَبِّرٍ ‏"‏ ‏.‏\hadithno{7189}\hadithtrans{Haritha b. Wahb al-KhuzaIi reported Allah's Messenger (ﷺ) as saying:May I not inform you about the inmates of Paradise? (And then informing about them) said: Every meek person who is considered to be humble and if they were to adjure in the name of Allah, Allah would certainly fulfil it. May I not inform you about the inmates of Hell-Fire? They are all proud, mean and haughty}}
\hadithdefcmd{muslim}{7190}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُبَّ أَشْعَثَ مَدْفُوعٍ بِالأَبْوَابِ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏\hadithno{7190}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:Many a people with dishevelled hair are driven away from the door (but they are so pious) that if they are to swear in the name of Allah, He would definitely fulfil that}}
\hadithdefcmd{muslim}{7191}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ، عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ النَّاقَةَ وَذَكَرَ الَّذِي عَقَرَهَا فَقَالَ ‏"‏ إِذِ انْبَعَثَ أَشْقَاهَا انْبَعَثَ بِهَا رَجُلٌ عَزِيزٌ عَارِمٌ مَنِيعٌ فِي رَهْطِهِ مِثْلُ أَبِي زَمْعَةَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ النِّسَاءَ فَوَعَظَ فِيهِنَّ ثُمَّ قَالَ ‏"‏ إِلاَمَ يَجْلِدُ أَحَدُكُمُ امْرَأَتَهُ ‏"‏ ‏.‏ فِي رِوَايَةِ أَبِي بَكْرٍ ‏"‏ جَلْدَ الأَمَةِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ ‏"‏ جَلْدَ الْعَبْدِ وَلَعَلَّهُ يُضَاجِعُهَا مِنْ آخِرِ يَوْمِهِ ‏"‏ ‏.‏ ثُمَّ وَعَظَهُمْ فِي ضَحِكِهِمْ مِنَ الضَّرْطَةِ فَقَالَ ‏"‏ إِلاَمَ يَضْحَكُ أَحَدُكُمْ مِمَّا يَفْعَلُ ‏"‏ ‏.‏\hadithno{7191}\hadithtrans{Abdullah b. Zam'a reported that Allah's Messenger (ﷺ) delivered an address and he made a mention of the dromedary and also made a mention of one (base person) who cut off Its hind legs, and he recited:" When the basest of them broke forth with mischief" (xei. 12). When A mischievous person, strong even because of the strength of a family like Abu Zam'a, broke forth. He then delivered instruction in regard to the women saying: There is amongst you who beats his woman, and in the narration on the authority of Abu Bakr, the words are: He flogs her like a slave-girl. And in the narration of Abu Kuraib (the words are): He flogs like a slave and then comforts his bed with the help of that at the end of the day, and he then advised in regard to laughing of people at the breaking of wind and said: One of you laughs at that which you yourself do}}
\hadithdefcmd{muslim}{7192}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ عَمْرَو بْنَ لُحَىِّ بْنِ قَمَعَةَ بْنِ خِنْدِفَ أَبَا بَنِي كَعْبٍ هَؤُلاَءِ يَجُرُّ قُصْبَهُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{7192}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:I saw 'Amr b. Luhayy b. Qam'a b. Khindif, brother of Bani Ka'b, dragging his Intestines in Fire}}
\hadithdefcmd{muslim}{7193}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ، شِهَابٍ قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ إِنَّ الْبَحِيرَةَ الَّتِي يُمْنَعُ دَرُّهَا لِلطَّوَاغِيتِ فَلاَ يَحْلُبُهَا أَحَدٌ مِنَ النَّاسِ وَأَمَّا السَّائِبَةُ الَّتِي كَانُوا يُسَيِّبُونَهَا لآلِهَتِهِمْ فَلاَ يُحْمَلُ عَلَيْهَا شَىْءٌ ‏.‏ وَقَالَ ابْنُ الْمُسَيَّبِ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ عَمْرَو بْنَ عَامِرٍ الْخُزَاعِيَّ يَجُرُّ قُصْبَهُ فِي النَّارِ وَكَانَ أَوَّلَ مَنْ سَيَّبَ السُّيُوبَ ‏"‏ ‏.‏\hadithno{7193}\hadithtrans{Sa'id b. Musayyib explained" al-bahira" as that animal which is not milked but for the idols. and none amongst the people milks them, and" as-sa'iba" as that animal which is let loose for the deities. Nothing is loaded over it, and Ibn Musayyib narrated that Abu Huraira stated that Allah's Messenger (ﷺ) said:I saw 'Amr b. 'Amir al-Khuzili dragging his intestines in fire and he was the first who devoted animals to deity}}
\hadithdefcmd{muslim}{7194}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صِنْفَانِ مِنْ أَهْلِ النَّارِ لَمْ أَرَهُمَا قَوْمٌ مَعَهُمْ سِيَاطٌ كَأَذْنَابِ الْبَقَرِ يَضْرِبُونَ بِهَا النَّاسَ وَنِسَاءٌ كَاسِيَاتٌ عَارِيَاتٌ مُمِيلاَتٌ مَائِلاَتٌ رُءُوسُهُنَّ كَأَسْنِمَةِ الْبُخْتِ الْمَائِلَةِ لاَ يَدْخُلْنَ الْجَنَّةَ وَلاَ يَجِدْنَ رِيحَهَا وَإِنَّ رِيحَهَا لَتُوجَدُ مِنْ مَسِيرَةِ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{7194}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Two are the types amongst the denizens of Hell, the one possessing whips like the tail of an ox and they flog people with their help. (The second one) the women who would be naked in spite of their being dressed, who are seduced (to wrong paths) and seduce others with their hair high like humps. These women would not get into Paradise and they would not perceive the odour of Paradise, although its frag- rance can be perceived from such and such distance (from great distance)}}
\hadithdefcmd{muslim}{7195}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا زَيْدٌ، - يَعْنِي ابْنَ حُبَابٍ - حَدَّثَنَا أَفْلَحُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ إِنْ طَالَتْ بِكَ مُدَّةٌ أَنْ تَرَى قَوْمًا فِي أَيْدِيهِمْ مِثْلُ أَذْنَابِ الْبَقَرِ يَغْدُونَ فِي غَضَبِ اللَّهِ وَيَرُوحُونَ فِي سَخَطِ اللَّهِ ‏"‏ ‏.‏\hadithno{7195}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If you survive for a time you would certainly see people who would have whips in their hands like the tail of an ox. They would get up in the morning under the wrath of Allah and they would get into the evening with the anger of Allah}}
\hadithdefcmd{muslim}{7196}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ وَعَبْدُ بْنُ حُمَيْدٍ قَالُوا حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ حَدَّثَنَا أَفْلَحُ بْنُ سَعِيدٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ طَالَتْ بِكَ مُدَّةٌ أَوْشَكْتَ أَنْ تَرَى قَوْمًا يَغْدُونَ فِي سَخَطِ اللَّهِ وَيَرُوحُونَ فِي لَعْنَتِهِ فِي أَيْدِيهِمْ مِثْلُ أَذْنَابِ الْبَقَرِ ‏"‏ ‏.‏\hadithno{7196}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If you live for a time, you would certainly see people get up (in the morning) in the wrath of Allah and getting into the evening under the curse of Allah, and there would be in their hands (whips) like the tail of an ox}}
\hadithdefcmd{muslim}{7197}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا مُوسَى بْنُ أَعْيَنَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، حَاتِمٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا قَيْسٌ، قَالَ سَمِعْتُ مُسْتَوْرِدًا، أَخَا بَنِي فِهْرٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ مَا الدُّنْيَا فِي الآخِرَةِ إِلاَّ مِثْلُ مَا يَجْعَلُ أَحَدُكُمْ إِصْبَعَهُ هَذِهِ - وَأَشَارَ يَحْيَى بِالسَّبَّابَةِ - فِي الْيَمِّ فَلْيَنْظُرْ بِمَ يَرْجِعُ ‏"‏ ‏.‏ وَفِي حَدِيثِهِمْ جَمِيعًا غَيْرَ يَحْيَى سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ذَلِكَ ‏.‏ وَفِي حَدِيثِ أَبِي أُسَامَةَ عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ أَخِي بَنِي فِهْرٍ وَفِي حَدِيثِهِ أَيْضًا قَالَ وَأَشَارَ إِسْمَاعِيلُ بِالإِبْهَامِ ‏.‏\hadithno{7197}\hadithtrans{This hadith has been narrated through five different chains of transmitters and all of them are narrated on the authority of Mustaurid, brother of Bani Fihr, that Allah's Messenger (ﷺ) said:By Allah, this world (is so insigni- ficant in comparison) to the Hereafter that if one of you should dip his finger- (and wnile saying this Yahyg pointed with his forefinger) -in the ocean and then he should see as to what has stuck to it. This hadith has been narrated through another chain of transmitters also but with a slight variation of wording}}
\hadithdefcmd{muslim}{7198}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حَاتِمِ بْنِ أَبِي صَغِيرَةَ، حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ حُفَاةً عُرَاةً غُرْلاً ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ النِّسَاءُ وَالرِّجَالُ جَمِيعًا يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ قَالَ صلى الله عليه وسلم ‏"‏ يَا عَائِشَةُ الأَمْرُ أَشَدُّ مِنْ أَنْ يَنْظُرَ بَعْضُهُمْ إِلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{7198}\hadithtrans{A'isha reported that she heard Allah's Messenger (ﷺ) as saying:The people would be assembled on the Day of Resurrection barefooted, naked and uncircumcised. I said: Allah's Messenger, will the male and the female be together on the Day and would they be looking at one another? Upon this Allah's Messenger (ﷺ) said: 'A'isha, the matter would be too serious for them to look to one another}}
\hadithdefcmd{muslim}{7199}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَاتِمِ، بْنِ أَبِي صَغِيرَةَ بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِي حَدِيثِهِ ‏ "‏ غُرْلاً ‏"‏ ‏.‏\hadithno{7199}\hadithtrans{This hadith has been narrated on the authority of Hatim b. Abi Saghira with the same chain of transmitters and there is no mention of the word" uncircum- cised}}
\hadithdefcmd{muslim}{7200}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي، عُمَرَ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ وَهُوَ يَقُولُ ‏ "‏ إِنَّكُمْ مُلاَقُو اللَّهِ مُشَاةً حُفَاةً عُرَاةً غُرْلاً ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ زُهَيْرٌ فِي حَدِيثِهِ يَخْطُبُ ‏.‏\hadithno{7200}\hadithtrans{Ibn Abbas reported that he heard Allah's Messenger (ﷺ) deliver an address and he was saying that they would meet Allah barefooted, naked and uncircumcised}}
\hadithdefcmd{muslim}{7201}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا بِمَوْعِظَةٍ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تُحْشَرُونَ إِلَى اللَّهِ حُفَاةً عُرَاةً غُرْلاً ‏\{‏ كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ‏\}‏ أَلاَ وَإِنَّ أَوَّلَ الْخَلاَئِقِ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ أَلاَ وَإِنَّهُ سَيُجَاءُ بِرِجَالٍ مِنْ أُمَّتِي فَيُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ فَأَقُولُ يَا رَبِّ أَصْحَابِي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏.‏ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏ وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ فَلَمَّا تَوَفَّيْتَنِي كُنْتَ أَنْتَ الرَّقِيبَ عَلَيْهِمْ وَأَنْتَ عَلَى كُلِّ شَىْءٍ شَهِيدٌ * إِنْ تُعَذِّبْهُمْ فَإِنَّهُمْ عِبَادُكَ وَإِنْ تَغْفِرْ لَهُمْ فَإِنَّكَ أَنْتَ الْعَزِيزُ الْحَكِيمُ‏\}‏ قَالَ فَيُقَالُ لِي إِنَّهُمْ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ ‏"‏ ‏.‏ وَفِي حَدِيثِ وَكِيعٍ وَمُعَاذٍ ‏"‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏ ‏.‏\hadithno{7201}\hadithtrans{This hadith has been narrated through other chains of transmitters on the authority of Ibn Abbas, (and) the words are:While Allah's Messenger (ﷺ) stood up to deliver a sermon, he said: 0 people, Allah would make you assemble barefooted, naked and uncircumcised (and then recited the words of the Qur'an):" As We created you for the first time, We shall repeat it. (It is) a promise (binding) upon us. Lo! We are to perform it, and the first person who would be clothed on the Day of Resurrection would be (Hadrat) Ibrahim (peace be upon him)" and, behold! some persons of my Ummah would be brought and taken to the left and I would say: My Lord, they are my companions, and it would be said: You do not know what they did after you, and I would say just as the pious servant (Hadrat 'Isa) said:, I was a witness regarding them as I remained among them and Thou art a witness over everything, so if Thou chastisest them, they are Thy servants and if Thou for- givest them, Thou art Mighty, Wise" (v. 117-118). And it would be said to him: They constantly turned to their heels since you left them. This hadith has been transmitted on the authority of Waki' and Mu'adh (and the words are):" What new things they fabricated}}
\hadithdefcmd{muslim}{7202}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، قَالاَ جَمِيعًا حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُحْشَرُ النَّاسُ عَلَى ثَلاَثِ طَرَائِقَ رَاغِبِينَ رَاهِبِينَ وَاثْنَانِ عَلَى بَعِيرٍ وَثَلاَثَةٌ عَلَى بَعِيرٍ وَأَرْبَعَةٌ عَلَى بَعِيرٍ وَعَشَرَةٌ عَلَى بَعِيرٍ وَتَحْشُرُ بَقِيَّتَهُمُ النَّارُ تَبِيتُ مَعَهُمْ حَيْثُ بَاتُوا وَتَقِيلُ مَعَهُمْ حَيْثُ قَالُوا وَتُصْبِحُ مَعَهُمْ حَيْثُ أَصْبَحُوا وَتُمْسِي مَعَهُمْ حَيْثُ أَمْسَوْا ‏"‏ ‏.‏\hadithno{7202}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying, The people will be assembled in three categories. Those desirous (of Paradise), fearing (Hell), coming two upon the came], three upon the camel, four upon the camel, ten upon the camel and the rest will be assembled, Hell-Fire being with them when they are at midday where they would spend the night and where they would spend the morning and where they would spend the evening}}
\hadithdefcmd{muslim}{7203}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، - يَعْنُونَ ابْنَ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏\{‏ يَوْمَ يَقُومُ النَّاسُ لِرَبِّ الْعَالَمِينَ‏\}‏ قَالَ ‏"‏ يَقُومُ أَحَدُهُمْ فِي رَشْحِهِ إِلَى أَنْصَافِ أُذُنَيْهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ الْمُثَنَّى قَالَ ‏"‏ يَقُومُ النَّاسُ ‏"‏ ‏.‏ لَمْ يَذْكُرْ يَوْمَ ‏.‏\hadithno{7203}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) as saying:When the people stand before Allah, the Lord of the worlds, each one of them would stand submerged into perspiration up to half of his ears, and there is no mention of the "day" in the hadith transmitted on the authority of Ibn Muthanni}}
\hadithdefcmd{muslim}{7204}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنَا أَنَسٌ يَعْنِي ابْنَ عِيَاضٍ، ح وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، كِلاَهُمَا عَنْ مُوسَى بْنِ عُقْبَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، وَعِيسَى بْنُ يُونُسَ، عَنِ ابْنِ عَوْنٍ، ح وَحَدَّثَنِي عَبْدُ، اللَّهِ بْنُ جَعْفَرِ بْنِ يَحْيَى حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنِي أَبُو نَصْرٍ التَّمَّارُ، حَدَّثَنَا حَمَّادُ، بْنُ سَلَمَةَ عَنْ أَيُّوبَ، ح وَحَدَّثَنَا الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ ‏.‏ غَيْرَ أَنَّ فِي حَدِيثِ مُوسَى بْنِ عُقْبَةَ وَصَالِحٍ ‏ "‏ حَتَّى يَغِيبَ أَحَدُهُمْ فِي رَشْحِهِ إِلَى أَنْصَافِ أُذُنَيْهِ ‏"‏ ‏.‏\hadithno{7204}\hadithtrans{This hadith has been transmitted on the authority of Ibn 'Umar but with a slight variation of wording (and the words are):" One of them would be completely submerged in perspiration up to half of his ears}}
\hadithdefcmd{muslim}{7205}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ ثَوْرٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَرَقَ يَوْمَ الْقِيَامَةِ لَيَذْهَبُ فِي الأَرْضِ سَبْعِينَ بَاعًا وَإِنَّهُ لَيَبْلُغُ إِلَى أَفْوَاهِ النَّاسِ أَوْ إِلَى آذَانِهِمْ ‏"‏ ‏.‏ يَشُكُّ ثَوْرٌ أَيَّهُمَا قَالَ ‏.‏\hadithno{7205}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:The perspiration would spread on the Day of Resurrection upon the earth to the extent of seventy cubits and it would reach up to their mouths or up to their ears. Thaur is not sure (which words) he used (mouth or ears)}}
\hadithdefcmd{muslim}{7206}{حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ، جَابِرٍ حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، حَدَّثَنِي الْمِقْدَادُ بْنُ الأَسْوَدِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ تُدْنَى الشَّمْسُ يَوْمَ الْقِيَامَةِ مِنَ الْخَلْقِ حَتَّى تَكُونَ مِنْهُمْ كَمِقْدَارِ مِيلٍ ‏"‏ ‏.‏ قَالَ سُلَيْمُ بْنُ عَامِرٍ فَوَاللَّهِ مَا أَدْرِي مَا يَعْنِي بِالْمِيلِ أَمَسَافَةَ الأَرْضِ أَمِ الْمِيلَ الَّذِي تُكْتَحَلُ بِهِ الْعَيْنُ ‏.‏ قَالَ ‏"‏ فَيَكُونُ النَّاسُ عَلَى قَدْرِ أَعْمَالِهِمْ فِي الْعَرَقِ فَمِنْهُمْ مَنْ يَكُونُ إِلَى كَعْبَيْهِ وَمِنْهُمْ مَنْ يَكُونُ إِلَى رُكْبَتَيْهِ وَمِنْهُمْ مَنْ يَكُونُ إِلَى حَقْوَيْهِ وَمِنْهُمْ مَنْ يُلْجِمُهُ الْعَرَقُ إِلْجَامًا ‏"‏ ‏.‏ قَالَ وَأَشَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ إِلَى فِيهِ ‏.‏\hadithno{7206}\hadithtrans{Miqdad b. Aswad reported:I heard Allah's Messenger (may peace he upon him) as saying: On the Day of Resurrection, the sun would draw so close to the people that there woum be left only a distance of one mile. Sulaim b. Amir said: By Allah, I do not know whether he meant by" mile" the mile of the (material) earth or dn instrument used for applying collyrium to the eye. (The Prophet is, however, reported to have said): The people would be submerged in perspiration according to their deeds, some up to their. knees, Some up to the waist and some would have the bridle of perspiration and, while saying this, Allah's Apostle (ﷺ) pointed his hand towards his mouth}}
\hadithdefcmd{muslim}{7207}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارِ بْنِ عُثْمَانَ، - وَاللَّفْظُ لأَبِي غَسَّانَ وَابْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِيَاضِ بْنِ حِمَارٍ الْمُجَاشِعِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَاتَ يَوْمٍ فِي خُطْبَتِهِ ‏"‏ أَلاَ إِنَّ رَبِّي أَمَرَنِي أَنْ أُعَلِّمَكُمْ مَا جَهِلْتُمْ مِمَّا عَلَّمَنِي يَوْمِي هَذَا كُلُّ مَالٍ نَحَلْتُهُ عَبْدًا حَلاَلٌ وَإِنِّي خَلَقْتُ عِبَادِي حُنَفَاءَ كُلَّهُمْ وَإِنَّهُمْ أَتَتْهُمُ الشَّيَاطِينُ فَاجْتَالَتْهُمْ عَنْ دِينِهِمْ وَحَرَّمَتْ عَلَيْهِمْ مَا أَحْلَلْتُ لَهُمْ وَأَمَرَتْهُمْ أَنْ يُشْرِكُوا بِي مَا لَمْ أُنْزِلْ بِهِ سُلْطَانًا وَإِنَّ اللَّهَ نَظَرَ إِلَى أَهْلِ الأَرْضِ فَمَقَتَهُمْ عَرَبَهُمْ وَعَجَمَهُمْ إِلاَّ بَقَايَا مِنْ أَهْلِ الْكِتَابِ وَقَالَ إِنَّمَا بَعَثْتُكَ لأَبْتَلِيَكَ وَأَبْتَلِيَ بِكَ وَأَنْزَلْتُ عَلَيْكَ كِتَابًا لاَ يَغْسِلُهُ الْمَاءُ تَقْرَؤُهُ نَائِمًا وَيَقْظَانَ وَإِنَّ اللَّهَ أَمَرَنِي أَنْ أُحَرِّقَ قُرَيْشًا فَقُلْتُ رَبِّ إِذًا يَثْلَغُوا رَأْسِي فَيَدَعُوهُ خُبْزَةً قَالَ اسْتَخْرِجْهُمْ كَمَا اسْتَخْرَجُوكَ وَاغْزُهُمْ نُغْزِكَ وَأَنْفِقْ فَسَنُنْفِقَ عَلَيْكَ وَابْعَثْ جَيْشًا نَبْعَثْ خَمْسَةً مِثْلَهُ وَقَاتِلْ بِمَنْ أَطَاعَكَ مَنْ عَصَاكَ ‏.‏ قَالَ وَأَهْلُ الْجَنَّةِ ثَلاَثَةٌ ذُو سُلْطَانٍ مُقْسِطٌ مُتَصَدِّقٌ مُوَفَّقٌ وَرَجُلٌ رَحِيمٌ رَقِيقُ الْقَلْبِ لِكُلِّ ذِي قُرْبَى وَمُسْلِمٍ وَعَفِيفٌ مُتَعَفِّفٌ ذُو عِيَالٍ - قَالَ - وَأَهْلُ النَّارِ خَمْسَةٌ الضَّعِيفُ الَّذِي لاَ زَبْرَ لَهُ الَّذِينَ هُمْ فِيكُمْ تَبَعًا لاَ يَتْبَعُونَ أَهْلاً وَلاَ مَالاً وَالْخَائِنُ الَّذِي لاَ يَخْفَى لَهُ طَمَعٌ وَإِنْ دَقَّ إِلاَّ خَانَهُ وَرَجُلٌ لاَ يُصْبِحُ وَلاَ يُمْسِي إِلاَّ وَهُوَ يُخَادِعُكَ عَنْ أَهْلِكَ وَمَالِكَ ‏"‏ ‏.‏ وَذَكَرَ الْبُخْلَ أَوِ الْكَذِبَ ‏"‏ وَالشِّنْظِيرُ الْفَحَّاشُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ أَبُو غَسَّانَ فِي حَدِيثِهِ ‏"‏ وَأَنْفِقْ فَسَنُنْفِقَ عَلَيْكَ ‏"‏ ‏.‏\hadithno{7207}\hadithtrans{Iyad b. Him-ar reported that Allah's Messenger (ﷺ), while delivering a sermon one day, said:Behold, my Lord commanded me that I should teach you which you do not know and which He has taught me today. (He has instructed thus): The property which I have conferred upon them is lawful for them. I have created My servants as one having a natural inclination to the worship of Allah but it is Satan who turns them away from the right religion and he makes unlawful what has been declared lawful for them and he commands them to ascribe partnership with Me, although he has no justification for that. And verily, Allah looked towards the people of the world and He showed hatred for the Arabs and the non-Arabs, but with the exception of some remnants from the People of the Book. And He (further) said: I have sent thee (the Holy Prophet) in order to put you to test and put (those to test) through you. And I sent the Book to you which cannot be washed away by water, so that you may recite it while in the state of wakefulness or sleep. Verily, Allah commanded me to burn (kill) the Quraish. I said: My Lord, they would break my head (like the tearing) of bread, and Allah said: You turn them out as they turned you out, you fight against them and We shall help you in this, you should spend and you would be conferred upon. You send an army and I would send an army five times greater than that. Fight against those who disobey you along with those who obey you. The inmates of Paradise are three: One who wields authority and is just and fair, one who Is truthful and has been endowed with power to do good deeds. And the person who is merciful and kind hearted towards his relatives and to every pious Muslim, and one who does not stretch his hand in spite of having a large family to support. And He said: The inmates of Hell are five: the weak who lack power to (avoid evil), the (carefree) who pursue (everything irrespective of the fact that it is good or evil) and who do not have any care for their family or for their wealth. And those dishonest whose greed cannot be concealed even in the case of minor things. And the third. who betray you. morning and evening, in regard to your family and your property. He also made a mention of the miser and the liar and those who are in the habit of abusing people and using obscene and foul language. Abu Ghassan in his narration did not make mention of" Spend and there would be spent for you}}
\hadithdefcmd{muslim}{7208}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ فِي حَدِيثِهِ ‏ "‏ كُلُّ مَالٍ نَحَلْتُهُ عَبْدًا حَلاَلٌ ‏"‏ ‏.‏\hadithno{7208}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7209}{حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، - صَاحِبِ الدَّسْتَوَائِيِّ - حَدَّثَنَا قَتَادَةُ، عَنْ مُطَرِّفٍ، عَنْ عِيَاضِ بْنِ حِمَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ ذَاتَ يَوْمٍ ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِي آخِرِهِ قَالَ يَحْيَى قَالَ شُعْبَةُ عَنْ قَتَادَةَ قَالَ سَمِعْتُ مُطَرِّفًا فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{7209}\hadithtrans{This hadith has been transmitted on the authority of 'Iyad b. Himar that Allah's Messenger (ﷺ) gave an address one day. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7210}{وَحَدَّثَنِي أَبُو عَمَّارٍ، حُسَيْنُ بْنُ حُرَيْثٍ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ، عَنْ مَطَرٍ، حَدَّثَنِي قَتَادَةُ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِيَاضِ بْنِ حِمَارٍ، أَخِي بَنِي مُجَاشِعٍ قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ خَطِيبًا فَقَالَ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ هِشَامٍ عَنْ قَتَادَةَ وَزَادَ فِيهِ ‏"‏ وَإِنَّ اللَّهَ أَوْحَى إِلَىَّ أَنْ تَوَاضَعُوا حَتَّى لاَ يَفْخَرَ أَحَدٌ عَلَى أَحَدٍ وَلاَ يَبْغِي أَحَدٌ عَلَى أَحَدٍ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِهِ ‏"‏ وَهُمْ فِيكُمْ تَبَعًا لاَ يَبْغُونَ أَهْلاً وَلاَ مَالاً ‏"‏ ‏.‏ فَقُلْتُ فَيَكُونُ ذَلِكَ يَا أَبَا عَبْدِ اللَّهِ قَالَ نَعَمْ وَاللَّهِ لَقَدْ أَدْرَكْتُهُمْ فِي الْجَاهِلِيَّةِ وَإِنَّ الرَّجُلَ لَيَرْعَى عَلَى الْحَىِّ مَا بِهِ إِلاَّ وَلِيدَتُهُمْ يَطَؤُهَا ‏.‏\hadithno{7210}\hadithtrans{Iyad. b. Himar reported tbat, while Allah's Messenger (ﷺ) was delivering an address, he stated that Allah commanded me The rest of the hadith is the same, and there is an addition in it:" Allah revealed to me that we should be humble amongst ourselves and none should show pride upon the others, And it does not behove one to do so, and He also said: There are among you people to follow not caring a bit for their family and property. Qatada said: Abu Abdullah, would this happen? Thereupon he said: Yes. By Allah, I found this in the days of ignorance that a person grazed the goat of a tribe and did not find anyone but their slave-girl (and he did not spare her) but committed adultery with her}}
\hadithdefcmd{muslim}{7211}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا مَاتَ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ يُقَالُ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{7211}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as say- ing:When any one of you dies, he is shown his seat (in the Hereafter) morning and evening; if he is amongst the inmates of Paradise (he is shown the seat) from amongst the inmates of Paradise and if he is one from amongst the denizens of Hell (he is shown the seat) from amongst the denizens of Hell, and it would be said to him: That is your seat until Allah raises you on the Day of Resurrection (and sends you to your proper seat)}}
\hadithdefcmd{muslim}{7212}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا مَاتَ الرَّجُلُ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَالْجَنَّةُ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَالنَّارُ ‏"‏ ‏.‏ قَالَ ‏"‏ ثُمَّ يُقَالُ هَذَا مَقْعَدُكَ الَّذِي تُبْعَثُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{7212}\hadithtrans{Ibn Umar reported that Allah's Apostle (ﷺ) said:When a person dies, he is shown his seat morning and evening. If he is one amongst the inmates of Paradise (he is shown his seat) in Paradise and if he is one amongst the denizens of Hell-Fire (he is shown his seat) in the Hell-Fire. Then it is said to him: That is your seat where you would be sent on the Day of Resurrection}}
\hadithdefcmd{muslim}{7213}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ وَأَخْبَرَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ أَبُو سَعِيدٍ وَلَمْ أَشْهَدْهُ مِنَ النَّبِيِّ صلى الله عليه وسلم وَلَكِنْ حَدَّثَنِيهِ زَيْدُ بْنُ ثَابِتٍ قَالَ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم فِي حَائِطٍ لِبَنِي النَّجَّارِ عَلَى بَغْلَةٍ لَهُ وَنَحْنُ مَعَهُ إِذْ حَادَتْ بِهِ فَكَادَتْ تُلْقِيهِ وَإِذَا أَقْبُرٌ سِتَّةٌ أَوْ خَمْسَةٌ أَوْ أَرْبَعَةٌ - قَالَ كَذَا كَانَ يَقُولُ الْجُرَيْرِيُّ - فَقَالَ ‏"‏ مَنْ يَعْرِفُ أَصْحَابَ هَذِهِ الأَقْبُرِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا ‏.‏ قَالَ ‏"‏ فَمَتَى مَاتَ هَؤُلاَءِ ‏"‏ ‏.‏ قَالَ مَاتُوا فِي الإِشْرَاكِ ‏.‏ فَقَالَ ‏"‏ إِنَّ هَذِهِ الأُمَّةَ تُبْتَلَى فِي قُبُورِهَا فَلَوْلاَ أَنْ لاَ تَدَافَنُوا لَدَعَوْتُ اللَّهَ أَنْ يُسْمِعَكُمْ مِنْ عَذَابِ الْقَبْرِ الَّذِي أَسْمَعُ مِنْهُ ‏"‏ ‏.‏ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ عَذَابِ النَّارِ ‏"‏ ‏.‏ قَالُوا نَعُوذُ بِاللَّهِ مِنْ عَذَابِ النَّارِ فَقَالَ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏ قَالُوا نَعُوذُ بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ ‏.‏ قَالَ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنَ الْفِتَنِ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ ‏"‏ ‏.‏ قَالُوا نَعُوذُ بِاللَّهِ مِنَ الْفِتَنِ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ قَالَ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ فِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ قَالُوا نَعُوذُ بِاللَّهِ مِنْ فِتْنَةِ الدَّجَّالِ ‏.‏\hadithno{7213}\hadithtrans{Abu Sa'id al-Khudri reported:I did not hear this hadith from Allah's Apostle (ﷺ) directly but it was Zaid b. Thabit who narrated it from him. As Allah's Apostle (ﷺ) was going along with us towards the dwellings of Bani an-Najjar, riding upon his pony, it shied and he was about to fall. He found four, five or six graves there. He said: Who amongst you knows about those lying in the graves? A person said: It is I. Thereupon he (the Holy Prophet) said: In what state did they die? He said: They died as polytheists. He said: These people are passing through the ordeal in the graves. If it were not the reason that you would stop burying (your dead) in the graves on listening to the torment in the grave which I am listening to, I would have certainly made you hear that. Then turning his face towards us, he said: Seek refuge with Allah from the torment of Hell. They said: We seek refuge with Allah from the torment of Hell. He said: Seek refuge with Allah from the torment of the grave. They said: We seek refuge with Allah from the torment of the grave. He said: Seek refuge with Allah from turmoil, its visible and invisible (aspects), and they said: We seek refuge with Allah from turmoil and its visible and invisible aspects and he said: Seek refuge with Allah from the turmoil of the Dajjal, and they said We seek refuge with Allah from the turmoil of the Dajjal}}
\hadithdefcmd{muslim}{7214}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ لاَ تَدَافَنُوا لَدَعَوْتُ اللَّهَ أَنْ يُسْمِعَكُمْ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{7214}\hadithtrans{Anas reported Allah's Apostle (ﷺ) as saying:If you were not (to abandon) the burying of the dead (in the grave), I would have certainly supplicated Allah that He should make you listen the torment of the grave}}
\hadithdefcmd{muslim}{7215}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، كُلُّهُمْ عَنْ شُعْبَةَ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ يَحْيَى الْقَطَّانِ، - وَاللَّفْظُ لِزُهَيْرٍ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَوْنُ، بْنُ أَبِي جُحَيْفَةَ عَنْ أَبِيهِ، عَنِ الْبَرَاءِ، عَنْ أَبِي أَيُّوبَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا غَرَبَتِ الشَّمْسُ فَسَمِعَ صَوْتًا فَقَالَ ‏ "‏ يَهُودُ تُعَذَّبُ فِي قُبُورِهَا ‏"‏ ‏.‏\hadithno{7215}\hadithtrans{This hadith has been narrated on the authority of Abu Ayyub through some other chains of transmitters (and the words are):" Allah's Messenger (ﷺ) went out after the sun had set and he heard some sound and said: It is the Jews who are being tormented in their graves}}
\hadithdefcmd{muslim}{7216}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ ‏"‏ ‏.‏ قَالَ ‏"‏ يَأْتِيهِ مَلَكَانِ فَيُقْعِدَانِهِ فَيَقُولاَنِ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ ‏"‏ ‏.‏ قَالَ ‏"‏ فَأَمَّا الْمُؤْمِنُ فَيَقُولُ أَشْهَدُ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ ‏"‏ فَيُقَالُ لَهُ انْظُرْ إِلَى مَقْعَدِكَ مِنَ النَّارِ قَدْ أَبْدَلَكَ اللَّهُ بِهِ مَقْعَدًا مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَيَرَاهُمَا جَمِيعًا ‏"‏ ‏.‏ قَالَ قَتَادَةُ وَذُكِرَ لَنَا أَنَّهُ يُفْسَحُ لَهُ فِي قَبْرِهِ سَبْعُونَ ذِرَاعًا وَيُمْلأُ عَلَيْهِ خَضِرًا إِلَى يَوْمِ يُبْعَثُونَ ‏.‏\hadithno{7216}\hadithtrans{Anas b. Malik reported Allah's Apostle (ﷺ) having said:When the servant is placed in his grave, his companions retrace their steps, and he hears the noise of their footsteps, two angels come to him and make him sit and say to him: What you have to say about this person (the Prophet)? If he is a believer, he would say: I bear testimony to the fact that he is a servant of Allah and His Messenger. Then it would be said to him: Look to your seat in the Hellfire, for Allah has substituted (the seat of yours) with a seat in Paradise. Allah's Messenger (ﷺ) said: He would be shown both the seats. Qatada said: It was mentioned to us that his grave (the grave of a believer) expands to seventy cubits and is full with verdure until the Day when they would be resurrected}}
\hadithdefcmd{muslim}{7217}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَيِّتَ إِذَا وُضِعَ فِي قَبْرِهِ إِنَّهُ لَيَسْمَعُ خَفْقَ نِعَالِهِمْ إِذَا انْصَرَفُوا ‏"‏ ‏.‏\hadithno{7217}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:When the dead body. is placed in the grave, he listens to the sound of the shoes (as his friends and relatives return after burying him)}}
\hadithdefcmd{muslim}{7218}{حَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَطَاءٍ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ ‏"‏ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ شَيْبَانَ عَنْ قَتَادَةَ ‏.‏\hadithno{7218}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) said:When the servant is placed in his grave and his friends retrace their steps. The rest of the hadith is the same as transmitted by Qatada}}
\hadithdefcmd{muslim}{7219}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارِ بْنِ عُثْمَانَ الْعَبْدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ‏\}‏ قَالَ ‏"‏ نَزَلَتْ فِي عَذَابِ الْقَبْرِ فَيُقَالُ لَهُ مَنْ رَبُّكَ فَيَقُولُ رَبِّيَ اللَّهُ وَنَبِيِّيَ مُحَمَّدٌ صلى الله عليه وسلم ‏.‏ فَذَلِكَ قَوْلُهُ عَزَّ وَجَلَّ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ‏\}‏ ‏"‏ ‏.‏\hadithno{7219}\hadithtrans{Al-Bara' b. `Azib reported Allah's Apostle (ﷺ) as saying:This verse: "Allah grants steadfastness to those who believe with firm word," was revealed in connection with the torment of the grave. It would be said to him: Who is your Lord? And he would say: Allah is my Lord and Muhammad is my Apostle (ﷺ), and that is (what is implied) by the words of Allah, the Exalted: "Allah keeps steadfast those who believe with firm word in this world and in the Hereafter}}
\hadithdefcmd{muslim}{7220}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنُونَ ابْنَ مَهْدِيٍّ - عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنْ خَيْثَمَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ‏\}‏ قَالَ نَزَلَتْ فِي عَذَابِ الْقَبْرِ ‏.‏\hadithno{7220}\hadithtrans{Al-Bara' b. 'Azib reported that this verse:"Allah keeps those who believe steadfast with firm word in this world and the Hereafter" was revealed in connection with the torment of the grave}}
\hadithdefcmd{muslim}{7221}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا بُدَيْلٌ، عَنْ عَبْدِ، اللَّهِ بْنِ شَقِيقٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏"‏ إِذَا خَرَجَتْ رُوحُ الْمُؤْمِنِ تَلَقَّاهَا مَلَكَانِ يُصْعِدَانِهَا ‏"‏ ‏.‏ قَالَ حَمَّادٌ فَذَكَرَ مِنْ طِيبِ رِيحِهَا وَذَكَرَ الْمِسْكَ ‏.‏ قَالَ ‏"‏ وَيَقُولُ أَهْلُ السَّمَاءِ رُوحٌ طَيِّبَةٌ جَاءَتْ مِنْ قِبَلِ الأَرْضِ صَلَّى اللَّهُ عَلَيْكِ وَعَلَى جَسَدٍ كُنْتِ تَعْمُرِينَهُ ‏.‏ فَيُنْطَلَقُ بِهِ إِلَى رَبِّهِ عَزَّ وَجَلَّ ثُمَّ يَقُولُ انْطَلِقُوا بِهِ إِلَى آخِرِ الأَجَلِ ‏"‏ ‏.‏ قَالَ ‏"‏ وَإِنَّ الْكَافِرَ إِذَا خَرَجَتْ رُوحُهُ - قَالَ حَمَّادٌ وَذَكَرَ مِنْ نَتْنِهَا وَذَكَرَ لَعْنًا - وَيَقُولُ أَهْلُ السَّمَاءِ رُوحٌ خَبِيثَةٌ جَاءَتْ مِنْ قِبَلِ الأَرْضِ ‏.‏ قَالَ فَيُقَالُ انْطَلِقُوا بِهِ إِلَى آخِرِ الأَجَلِ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَرَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم رَيْطَةً كَانَتْ عَلَيْهِ عَلَى أَنْفِهِ هَكَذَا ‏.‏\hadithno{7221}\hadithtrans{Abu Huraira reported:When the soul of a believer would go out (of his body) it would be received bv two angels who would take it to the sky. Hammad (one of the narrators in the chain of transmitters) mentioned the swetness of its odour, (and further said) that the dwellers of the sky say: Here comes the pious soul from the side of the earth Let there be blessings of Allah upon the body in which it resides. And it is carried (by the angels) to its Lord, the Exalted and Glorious. He would say: Take it to its destined end. And if he is a nonbeliever and as it (the soul) leaves the body-Hammad made a mention of its foul smell and of its being cursed-the dwellers of the sky say: There comes a dirty soul from the side of the earth, and it would be said: Take it to its destined end. Abu Huraira reported that Allah's Messenger (ﷺ) put a thin cloth which was with him upon his nose while making a mention (of the foul smell) of the soul of a non-believer}}
\hadithdefcmd{muslim}{7222}{حَدَّثَنِي إِسْحَاقُ بْنُ عُمَرَ بْنِ سَلِيطٍ الْهُذَلِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، قَالَ قَالَ أَنَسٌ كُنْتُ مَعَ عُمَرَ ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا مَعَ عُمَرَ بَيْنَ مَكَّةَ وَالْمَدِينَةِ فَتَرَاءَيْنَا الْهِلاَلَ وَكُنْتُ رَجُلاً حَدِيدَ الْبَصَرِ فَرَأَيْتُهُ وَلَيْسَ أَحَدٌ يَزْعُمُ أَنَّهُ رَآهُ غَيْرِي - قَالَ - فَجَعَلْتُ أَقُولُ لِعُمَرَ أَمَا تَرَاهُ فَجَعَلَ لاَ يَرَاهُ - قَالَ - يَقُولُ عُمَرُ سَأَرَاهُ وَأَنَا مُسْتَلْقٍ عَلَى فِرَاشِي ‏.‏ ثُمَّ أَنْشَأَ يُحَدِّثُنَا عَنْ أَهْلِ بَدْرٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُرِينَا مَصَارِعَ أَهْلِ بَدْرِ بِالأَمْسِ يَقُولُ ‏"‏ هَذَا مَصْرَعُ فُلاَنٍ غَدًا إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ فَقَالَ عُمَرُ فَوَالَّذِي بَعَثَهُ بِالْحَقِّ مَا أَخْطَئُوا الْحُدُودَ الَّتِي حَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَجُعِلُوا فِي بِئْرٍ بَعْضُهُمْ عَلَى بَعْضٍ فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَهَى إِلَيْهِمْ فَقَالَ ‏"‏ يَا فُلاَنَ بْنَ فُلاَنٍ وَيَا فُلاَنَ بْنَ فُلاَنٍ هَلْ وَجَدْتُمْ مَا وَعَدَكُمُ اللَّهُ وَرَسُولُهُ حَقًّا فَإِنِّي قَدْ وَجَدْتُ مَا وَعَدَنِيَ اللَّهُ حَقًّا ‏"‏ ‏.‏ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَيْفَ تُكَلِّمُ أَجْسَادًا لاَ أَرْوَاحَ فِيهَا قَالَ ‏"‏ مَا أَنْتُمْ بِأَسْمَعَ لِمَا أَقُولُ مِنْهُمْ غَيْرَ أَنَّهُمْ لاَ يَسْتَطِيعُونَ أَنْ يَرُدُّوا عَلَىَّ شَيْئًا ‏"‏ ‏.‏\hadithno{7222}\hadithtrans{Anas b. Malik reported:We were along with Umar between Mecca and Medina that we began to look for the new moon. And I was a man with sharp eye- sight, so I could see it, but none except me saw it. I began to say to 'Umar: Don't you see it? But he would not see it. Thereupon Umar said: I would soon be able to see it (when it will shine more brightly). I lay upon bed. He then made a mention of the people of Badr to us and said: Allah's Messenger (ﷺ) showed us one day before (the actual battle) the place of death of the people (participating) in (the Battle) of Badr and he was saying: This would be the place of death of so and so tomorrow, if Allah wills. Umar said: By Him Who sent him with truth, they did not miss the places (of their death) which Allah's Messenger (ﷺ) had pointed for them. Then they were all thrown in a well one after another. Allah's Messenger (ﷺ) then went to them and said: O, so and so, the son of so and so; O so and so, the son of so and so, have you found correct what Allah and His Messenger had promised you? I have, however, found absolutely true what Allah had promised with me. Umar said: Allah's Messenger, how are you talking with the bodies without soul in them. Thereupon he said: You cannot hear more distinctly than (their hearing) of what I say, but with this exception that they have not power to make any reply}}
\hadithdefcmd{muslim}{7223}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ، مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ قَتْلَى بَدْرٍ ثَلاَثًا ثُمَّ أَتَاهُمْ فَقَامَ عَلَيْهِمْ فَنَادَاهُمْ فَقَالَ ‏"‏ يَا أَبَا جَهْلِ بْنَ هِشَامٍ يَا أُمَيَّةَ بْنَ خَلَفٍ يَا عُتْبَةَ بْنَ رَبِيعَةَ يَا شَيْبَةَ بْنَ رَبِيعَةَ أَلَيْسَ قَدْ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا فَإِنِّي قَدْ وَجَدْتُ مَا وَعَدَنِي رَبِّي حَقًّا ‏"‏ ‏.‏ فَسَمِعَ عُمَرُ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ يَسْمَعُوا وَأَنَّى يُجِيبُوا وَقَدْ جَيَّفُوا قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا أَنْتُمْ بِأَسْمَعَ لِمَا أَقُولُ مِنْهُمْ وَلَكِنَّهُمْ لاَ يَقْدِرُونَ أَنْ يُجِيبُوا ‏"‏ ‏.‏ ثُمَّ أَمَرَ بِهِمْ فَسُحِبُوا فَأُلْقُوا فِي قَلِيبِ بَدْرٍ ‏.‏\hadithno{7223}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) let the dead bodies of the unbelievers who fought in Badr (lie unburied) for three days. He then came to them and sat by their side and called them and said:O Abu Jahl b. Hisham, O Umayya b. Khalaf, O Utba b. Rab'ila, O Shaiba b. Rabi'a, have you not found what your Lord had promised with you to be correct? As for me, I have found the promises of my Lord to be (perfectly) correct. Umar listened to the words of Allah's Apostle (ﷺ) and said: Allah's Messenger, how do they listen and respond to you? They are dead and their bodies have decayed. Thereupon he (the Holy Prophet) said: By Him in Whose Hand is my life, what I am saying to them, even you cannot hear more distinctly than they, but they lack the power to reply. Then'he commanded that they should be buried in the well of Badr}}
\hadithdefcmd{muslim}{7224}{حَدَّثَنِي يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي طَلْحَةَ، ح وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، قَالَ ذَكَرَ لَنَا أَنَسُ بْنُ مَالِكٍ عَنْ أَبِي طَلْحَةَ، قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ وَظَهَرَ عَلَيْهِمْ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَمَرَ بِبِضْعَةٍ وَعِشْرِينَ رَجُلاً - وَفِي حَدِيثِ رَوْحٍ بِأَرْبَعَةٍ وَعِشْرِينَ رَجُلاً - مِنْ صَنَادِيدِ قُرَيْشٍ فَأُلْقُوا فِي طَوِيٍّ مِنْ أَطْوَاءِ بَدْرٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ ثَابِتٍ عَنْ أَنَسٍ ‏.‏\hadithno{7224}\hadithtrans{Aba Talha reported:When it was the Day of Badr and Allah's Apostle (ﷺ) had gained victory over them (the Meccans), he commanded more than twenty persons, and in another hadith these are counted as twenty-four persons, from the non-believers of the Quraish to be thrown into the well of Badr. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7225}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ حُجْرٍ، جَمِيعًا عَنْ إِسْمَاعِيلَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حُوسِبَ يَوْمَ الْقِيَامَةِ عُذِّبَ ‏"‏ ‏.‏ فَقُلْتُ أَلَيْسَ قَدْ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا‏\}‏ فَقَالَ ‏"‏ لَيْسَ ذَاكِ الْحِسَابُ إِنَّمَا ذَاكِ الْعَرْضُ مَنْ نُوقِشَ الْحِسَابَ يَوْمَ الْقِيَامَةِ عُذِّبَ ‏"‏ ‏.‏\hadithno{7225}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) said:He who is taken to account on the Day of Resurrection is in fact put to torment. I said: Has Allah, the Exalted and Glorious, not said this: 'He will be made subject to an easy reckoning" (Ixxxiv. 8)? Thereupon he said: (What it implies) is not the actual reckoning, but only the presentation of one's deeds to Him. He who is thoroughly examined in reckoning is put to torment}}
\hadithdefcmd{muslim}{7226}{حَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7226}\hadithtrans{This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{7227}{وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرِ بْنِ الْحَكَمِ الْعَبْدِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الْقَطَّانَ - حَدَّثَنَا أَبُو يُونُسَ الْقُشَيْرِيُّ، حَدَّثَنَا ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ أَحَدٌ يُحَاسَبُ إِلاَّ هَلَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَلَيْسَ اللَّهُ يَقُولُ حِسَابًا يَسِيرًا قَالَ ‏"‏ ذَاكِ الْعَرْضُ وَلَكِنْ مَنْ نُوقِشَ الْحِسَابَ هَلَكَ ‏"‏ ‏.‏\hadithno{7227}\hadithtrans{A'isha reported Allah's Apostle (ﷺ) as saying:Everyone who is reckoned thoroughly is undone. I said: Allah's Messenger, has Allah not called (reckoning) as easy reckoning? Thereupon he said.. It implies only presenta- tion of (one's deeds to Him), but if one is thoroughly examined in reckoning, he in fact is undone}}
\hadithdefcmd{muslim}{7228}{وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنِي يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُثْمَانَ بْنِ، الأَسْوَدِ عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نُوقِشَ الْحِسَابَ هَلَكَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ أَبِي يُونُسَ ‏.‏\hadithno{7228}\hadithtrans{A'isha reported Allah's Apostle (ﷺ) as saying:He who is examined thoroughly In reckoning is undone}}
\hadithdefcmd{muslim}{7229}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَحْيَى بْنُ زَكَرِيَّاءَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَبْلَ وَفَاتِهِ بِثَلاَثٍ يَقُولُ ‏ "‏ لاَ يَمُوتَنَّ أَحَدُكُمْ إِلاَّ وَهُوَ يُحْسِنُ بِاللَّهِ الظَّنَّ ‏"‏ ‏.‏\hadithno{7229}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) as saying three days before his death: None of you should court death but only hoping good from Allah}}
\hadithdefcmd{muslim}{7230}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، وَأَبُو مُعَاوِيَةَ كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{7230}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{7231}{وَحَدَّثَنِي أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ مَعْبَدٍ حَدَّثَنَا أَبُو النُّعْمَانِ، عَارِمٌ حَدَّثَنَا مَهْدِيُّ بْنُ، مَيْمُونٍ حَدَّثَنَا وَاصِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبْلَ مَوْتِهِ بِثَلاَثَةِ أَيَّامٍ يَقُولُ ‏ "‏ لاَ يَمُوتَنَّ أَحَدُكُمْ إِلاَّ وَهُوَ يُحْسِنُ الظَّنَّ بِاللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{7231}\hadithtrans{Jabir b. 'Abdullah al-Ansari reported:I heard Allah's Messenger (ﷺ) say three days before his death: None of you should die but hoping only good from Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{7232}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُبْعَثُ كُلُّ عَبْدٍ عَلَى مَا مَاتَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{7232}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) as saying. Every servant would be raised (in the same very state) in which he dies}}
\hadithdefcmd{muslim}{7233}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَقُلْ سَمِعْتُ ‏.‏\hadithno{7233}\hadithtrans{This hadith has been transmitted on the authority of A'mash but with a slight variation of wording}}
\hadithdefcmd{muslim}{7234}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ أَخْبَرَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَرَادَ اللَّهُ بِقَوْمٍ عَذَابًا أَصَابَ الْعَذَابُ مَنْ كَانَ فِيهِمْ ثُمَّ بُعِثُوا عَلَى أَعْمَالِهِمْ ‏"‏ ‏.‏\hadithno{7234}\hadithtrans{Abdullah b. Umar reported:I heard Allah's Messenger (ﷺ) as saying: When Allah intends to chastise a people, He chastises all of them then they would be raised according to their deeds}}
